package Monitoring::GLPlugin::SNMP::MibsAndOids::CHECKPOINTMIB;

$Monitoring::GLPlugin::SNMP::MibsAndOids::origin->{'CHECKPOINT-MIB'} = {
  url => '',
  name => 'CHECKPOINT-MIB',
};

$Monitoring::GLPlugin::SNMP::MibsAndOids::mib_ids->{'CHECKPOINT-MIB'} =
    '1.3.6.1.4.1.2620.1';

$Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'CHECKPOINT-MIB'} = {
  'checkpoint' => '1.3.6.1.4.1.2620',
  'products' => '1.3.6.1.4.1.2620.1',
  'fw' => '1.3.6.1.4.1.2620.1.1',
  'fwTrapPrefix' => '1.3.6.1.4.1.2620.1.1.0',
  'fwModuleState' => '1.3.6.1.4.1.2620.1.1.1',
  'fwFilterName' => '1.3.6.1.4.1.2620.1.1.2',
  'fwFilterDate' => '1.3.6.1.4.1.2620.1.1.3',
  'fwAccepted' => '1.3.6.1.4.1.2620.1.1.4',
  'fwRejected' => '1.3.6.1.4.1.2620.1.1.5',
  'fwDropped' => '1.3.6.1.4.1.2620.1.1.6',
  'fwLogged' => '1.3.6.1.4.1.2620.1.1.7',
  'fwMajor' => '1.3.6.1.4.1.2620.1.1.8',
  'fwMinor' => '1.3.6.1.4.1.2620.1.1.9',
  'fwProduct' => '1.3.6.1.4.1.2620.1.1.10',
  'fwEvent' => '1.3.6.1.4.1.2620.1.1.11',
  'fwSICTrustState' => '1.3.6.1.4.1.2620.1.1.12',
  'fwProdName' => '1.3.6.1.4.1.2620.1.1.21',
  'fwVerMajor' => '1.3.6.1.4.1.2620.1.1.22',
  'fwVerMinor' => '1.3.6.1.4.1.2620.1.1.23',
  'fwKernelBuild' => '1.3.6.1.4.1.2620.1.1.24',
  'fwPolicyStat' => '1.3.6.1.4.1.2620.1.1.25',
  'fwPolicyName' => '1.3.6.1.4.1.2620.1.1.25.1',
  'fwInstallTime' => '1.3.6.1.4.1.2620.1.1.25.2',
  'fwNumConn' => '1.3.6.1.4.1.2620.1.1.25.3',
  'fwPeakNumConn' => '1.3.6.1.4.1.2620.1.1.25.4',
  'fwIfTable' => '1.3.6.1.4.1.2620.1.1.25.5',
  'fwIfEntry' => '1.3.6.1.4.1.2620.1.1.25.5.1',
  'fwIfIndex' => '1.3.6.1.4.1.2620.1.1.25.5.1.1',
  'fwIfName' => '1.3.6.1.4.1.2620.1.1.25.5.1.2',
  'fwAcceptPcktsIn' => '1.3.6.1.4.1.2620.1.1.25.5.1.5',
  'fwAcceptPcktsOut' => '1.3.6.1.4.1.2620.1.1.25.5.1.6',
  'fwAcceptBytesIn' => '1.3.6.1.4.1.2620.1.1.25.5.1.7',
  'fwAcceptBytesOut' => '1.3.6.1.4.1.2620.1.1.25.5.1.8',
  'fwDropPcktsIn' => '1.3.6.1.4.1.2620.1.1.25.5.1.9',
  'fwDropPcktsOut' => '1.3.6.1.4.1.2620.1.1.25.5.1.10',
  'fwRejectPcktsIn' => '1.3.6.1.4.1.2620.1.1.25.5.1.11',
  'fwRejectPcktsOut' => '1.3.6.1.4.1.2620.1.1.25.5.1.12',
  'fwLogIn' => '1.3.6.1.4.1.2620.1.1.25.5.1.13',
  'fwLogOut' => '1.3.6.1.4.1.2620.1.1.25.5.1.14',
  'fwPacketsRate' => '1.3.6.1.4.1.2620.1.1.25.6',
  'fwAcceptedBytesTotalRate' => '1.3.6.1.4.1.2620.1.1.25.8',
  'fwDroppedBytesTotalRate' => '1.3.6.1.4.1.2620.1.1.25.9',
  'fwConnTableLimit' => '1.3.6.1.4.1.2620.1.1.25.10',
  'fwDroppedTotalRate' => '1.3.6.1.4.1.2620.1.1.25.16',
  'fwPerfStat' => '1.3.6.1.4.1.2620.1.1.26',
  'fwHmem' => '1.3.6.1.4.1.2620.1.1.26.1',
  'fwHmem-block-size' => '1.3.6.1.4.1.2620.1.1.26.1.1',
  'fwHmem-requested-bytes' => '1.3.6.1.4.1.2620.1.1.26.1.2',
  'fwHmem-initial-allocated-bytes' => '1.3.6.1.4.1.2620.1.1.26.1.3',
  'fwHmem-initial-allocated-blocks' => '1.3.6.1.4.1.2620.1.1.26.1.4',
  'fwHmem-initial-allocated-pools' => '1.3.6.1.4.1.2620.1.1.26.1.5',
  'fwHmem-current-allocated-bytes' => '1.3.6.1.4.1.2620.1.1.26.1.6',
  'fwHmem-current-allocated-blocks' => '1.3.6.1.4.1.2620.1.1.26.1.7',
  'fwHmem-current-allocated-pools' => '1.3.6.1.4.1.2620.1.1.26.1.8',
  'fwHmem-maximum-bytes' => '1.3.6.1.4.1.2620.1.1.26.1.9',
  'fwHmem-maximum-pools' => '1.3.6.1.4.1.2620.1.1.26.1.10',
  'fwHmem-bytes-used' => '1.3.6.1.4.1.2620.1.1.26.1.11',
  'fwHmem-blocks-used' => '1.3.6.1.4.1.2620.1.1.26.1.12',
  'fwHmem-bytes-unused' => '1.3.6.1.4.1.2620.1.1.26.1.13',
  'fwHmem-blocks-unused' => '1.3.6.1.4.1.2620.1.1.26.1.14',
  'fwHmem-bytes-peak' => '1.3.6.1.4.1.2620.1.1.26.1.15',
  'fwHmem-blocks-peak' => '1.3.6.1.4.1.2620.1.1.26.1.16',
  'fwHmem-bytes-internal-use' => '1.3.6.1.4.1.2620.1.1.26.1.17',
  'fwHmem-number-of-items' => '1.3.6.1.4.1.2620.1.1.26.1.18',
  'fwHmem-alloc-operations' => '1.3.6.1.4.1.2620.1.1.26.1.19',
  'fwHmem-free-operations' => '1.3.6.1.4.1.2620.1.1.26.1.20',
  'fwHmem-failed-alloc' => '1.3.6.1.4.1.2620.1.1.26.1.21',
  'fwHmem-failed-free' => '1.3.6.1.4.1.2620.1.1.26.1.22',
  'fwKmem' => '1.3.6.1.4.1.2620.1.1.26.2',
  'fwKmem-system-physical-mem' => '1.3.6.1.4.1.2620.1.1.26.2.1',
  'fwKmem-available-physical-mem' => '1.3.6.1.4.1.2620.1.1.26.2.2',
  'fwKmem-aix-heap-size' => '1.3.6.1.4.1.2620.1.1.26.2.3',
  'fwKmem-bytes-used' => '1.3.6.1.4.1.2620.1.1.26.2.4',
  'fwKmem-blocking-bytes-used' => '1.3.6.1.4.1.2620.1.1.26.2.5',
  'fwKmem-non-blocking-bytes-used' => '1.3.6.1.4.1.2620.1.1.26.2.6',
  'fwKmem-bytes-unused' => '1.3.6.1.4.1.2620.1.1.26.2.7',
  'fwKmem-bytes-peak' => '1.3.6.1.4.1.2620.1.1.26.2.8',
  'fwKmem-blocking-bytes-peak' => '1.3.6.1.4.1.2620.1.1.26.2.9',
  'fwKmem-non-blocking-bytes-peak' => '1.3.6.1.4.1.2620.1.1.26.2.10',
  'fwKmem-bytes-internal-use' => '1.3.6.1.4.1.2620.1.1.26.2.11',
  'fwKmem-number-of-items' => '1.3.6.1.4.1.2620.1.1.26.2.12',
  'fwKmem-alloc-operations' => '1.3.6.1.4.1.2620.1.1.26.2.13',
  'fwKmem-free-operations' => '1.3.6.1.4.1.2620.1.1.26.2.14',
  'fwKmem-failed-alloc' => '1.3.6.1.4.1.2620.1.1.26.2.15',
  'fwKmem-failed-free' => '1.3.6.1.4.1.2620.1.1.26.2.16',
  'fwInspect' => '1.3.6.1.4.1.2620.1.1.26.3',
  'fwInspect-packets' => '1.3.6.1.4.1.2620.1.1.26.3.1',
  'fwInspect-operations' => '1.3.6.1.4.1.2620.1.1.26.3.2',
  'fwInspect-lookups' => '1.3.6.1.4.1.2620.1.1.26.3.3',
  'fwInspect-record' => '1.3.6.1.4.1.2620.1.1.26.3.4',
  'fwInspect-extract' => '1.3.6.1.4.1.2620.1.1.26.3.5',
  'fwCookies' => '1.3.6.1.4.1.2620.1.1.26.4',
  'fwCookies-total' => '1.3.6.1.4.1.2620.1.1.26.4.1',
  'fwCookies-allocfwCookies-total' => '1.3.6.1.4.1.2620.1.1.26.4.2',
  'fwCookies-freefwCookies-total' => '1.3.6.1.4.1.2620.1.1.26.4.3',
  'fwCookies-dupfwCookies-total' => '1.3.6.1.4.1.2620.1.1.26.4.4',
  'fwCookies-getfwCookies-total' => '1.3.6.1.4.1.2620.1.1.26.4.5',
  'fwCookies-putfwCookies-total' => '1.3.6.1.4.1.2620.1.1.26.4.6',
  'fwCookies-lenfwCookies-total' => '1.3.6.1.4.1.2620.1.1.26.4.7',
  'fwChains' => '1.3.6.1.4.1.2620.1.1.26.5',
  'fwChains-alloc' => '1.3.6.1.4.1.2620.1.1.26.5.1',
  'fwChains-free' => '1.3.6.1.4.1.2620.1.1.26.5.2',
  'fwFragments' => '1.3.6.1.4.1.2620.1.1.26.6',
  'fwFrag-fragments' => '1.3.6.1.4.1.2620.1.1.26.6.1',
  'fwFrag-expired' => '1.3.6.1.4.1.2620.1.1.26.6.2',
  'fwFrag-packets' => '1.3.6.1.4.1.2620.1.1.26.6.3',
  'fwUfp' => '1.3.6.1.4.1.2620.1.1.26.8',
  'fwUfpHitRatio' => '1.3.6.1.4.1.2620.1.1.26.8.1',
  'fwUfpInspected' => '1.3.6.1.4.1.2620.1.1.26.8.2',
  'fwUfpHits' => '1.3.6.1.4.1.2620.1.1.26.8.3',
  'fwSS' => '1.3.6.1.4.1.2620.1.1.26.9',
  'fwSS-http' => '1.3.6.1.4.1.2620.1.1.26.9.1',
  'fwSS-http-pid' => '1.3.6.1.4.1.2620.1.1.26.9.1.1',
  'fwSS-http-proto' => '1.3.6.1.4.1.2620.1.1.26.9.1.2',
  'fwSS-http-port' => '1.3.6.1.4.1.2620.1.1.26.9.1.3',
  'fwSS-http-logical-port' => '1.3.6.1.4.1.2620.1.1.26.9.1.4',
  'fwSS-http-max-avail-socket' => '1.3.6.1.4.1.2620.1.1.26.9.1.5',
  'fwSS-http-socket-in-use-max' => '1.3.6.1.4.1.2620.1.1.26.9.1.6',
  'fwSS-http-socket-in-use-curr' => '1.3.6.1.4.1.2620.1.1.26.9.1.7',
  'fwSS-http-socket-in-use-count' => '1.3.6.1.4.1.2620.1.1.26.9.1.8',
  'fwSS-http-sess-max' => '1.3.6.1.4.1.2620.1.1.26.9.1.9',
  'fwSS-http-sess-curr' => '1.3.6.1.4.1.2620.1.1.26.9.1.10',
  'fwSS-http-sess-count' => '1.3.6.1.4.1.2620.1.1.26.9.1.11',
  'fwSS-http-auth-sess-max' => '1.3.6.1.4.1.2620.1.1.26.9.1.12',
  'fwSS-http-auth-sess-curr' => '1.3.6.1.4.1.2620.1.1.26.9.1.13',
  'fwSS-http-auth-sess-count' => '1.3.6.1.4.1.2620.1.1.26.9.1.14',
  'fwSS-http-accepted-sess' => '1.3.6.1.4.1.2620.1.1.26.9.1.15',
  'fwSS-http-rejected-sess' => '1.3.6.1.4.1.2620.1.1.26.9.1.16',
  'fwSS-http-auth-failures' => '1.3.6.1.4.1.2620.1.1.26.9.1.17',
  'fwSS-http-ops-cvp-sess-max' => '1.3.6.1.4.1.2620.1.1.26.9.1.18',
  'fwSS-http-ops-cvp-sess-curr' => '1.3.6.1.4.1.2620.1.1.26.9.1.19',
  'fwSS-http-ops-cvp-sess-count' => '1.3.6.1.4.1.2620.1.1.26.9.1.20',
  'fwSS-http-ops-cvp-rej-sess' => '1.3.6.1.4.1.2620.1.1.26.9.1.21',
  'fwSS-http-ssl-encryp-sess-max' => '1.3.6.1.4.1.2620.1.1.26.9.1.22',
  'fwSS-http-ssl-encryp-sess-curr' => '1.3.6.1.4.1.2620.1.1.26.9.1.23',
  'fwSS-http-ssl-encryp-sess-count' => '1.3.6.1.4.1.2620.1.1.26.9.1.24',
  'fwSS-http-transp-sess-max' => '1.3.6.1.4.1.2620.1.1.26.9.1.25',
  'fwSS-http-transp-sess-curr' => '1.3.6.1.4.1.2620.1.1.26.9.1.26',
  'fwSS-http-transp-sess-count' => '1.3.6.1.4.1.2620.1.1.26.9.1.27',
  'fwSS-http-proxied-sess-max' => '1.3.6.1.4.1.2620.1.1.26.9.1.28',
  'fwSS-http-proxied-sess-curr' => '1.3.6.1.4.1.2620.1.1.26.9.1.29',
  'fwSS-http-proxied-sess-count' => '1.3.6.1.4.1.2620.1.1.26.9.1.30',
  'fwSS-http-tunneled-sess-max' => '1.3.6.1.4.1.2620.1.1.26.9.1.31',
  'fwSS-http-tunneled-sess-curr' => '1.3.6.1.4.1.2620.1.1.26.9.1.32',
  'fwSS-http-tunneled-sess-count' => '1.3.6.1.4.1.2620.1.1.26.9.1.33',
  'fwSS-http-ftp-sess-max' => '1.3.6.1.4.1.2620.1.1.26.9.1.34',
  'fwSS-http-ftp-sess-curr' => '1.3.6.1.4.1.2620.1.1.26.9.1.35',
  'fwSS-http-ftp-sess-count' => '1.3.6.1.4.1.2620.1.1.26.9.1.36',
  'fwSS-http-time-stamp' => '1.3.6.1.4.1.2620.1.1.26.9.1.37',
  'fwSS-http-is-alive' => '1.3.6.1.4.1.2620.1.1.26.9.1.38',
  'fwSS-http-blocked-cnt' => '1.3.6.1.4.1.2620.1.1.26.9.1.39',
  'fwSS-http-blocked-total' => '1.3.6.1.4.1.2620.1.1.26.9.1.40',
  'fwSS-http-scanned-total' => '1.3.6.1.4.1.2620.1.1.26.9.1.41',
  'fwSS-http-blocked-by-file-type' => '1.3.6.1.4.1.2620.1.1.26.9.1.42',
  'fwSS-http-blocked-by-size-limit' => '1.3.6.1.4.1.2620.1.1.26.9.1.43',
  'fwSS-http-blocked-by-archive-limit' => '1.3.6.1.4.1.2620.1.1.26.9.1.44',
  'fwSS-http-blocked-by-internal-error' => '1.3.6.1.4.1.2620.1.1.26.9.1.45',
  'fwSS-http-passed-cnt' => '1.3.6.1.4.1.2620.1.1.26.9.1.46',
  'fwSS-http-passed-by-file-type' => '1.3.6.1.4.1.2620.1.1.26.9.1.47',
  'fwSS-http-passed-by-size-limit' => '1.3.6.1.4.1.2620.1.1.26.9.1.48',
  'fwSS-http-passed-by-archive-limit' => '1.3.6.1.4.1.2620.1.1.26.9.1.49',
  'fwSS-http-passed-by-internal-error' => '1.3.6.1.4.1.2620.1.1.26.9.1.50',
  'fwSS-http-passed-total' => '1.3.6.1.4.1.2620.1.1.26.9.1.51',
  'fwSS-http-blocked-by-AV-settings' => '1.3.6.1.4.1.2620.1.1.26.9.1.52',
  'fwSS-http-passed-by-AV-settings' => '1.3.6.1.4.1.2620.1.1.26.9.1.53',
  'fwSS-http-blocked-by-URL-filter-category' => '1.3.6.1.4.1.2620.1.1.26.9.1.54',
  'fwSS-http-blocked-by-URL-block-list' => '1.3.6.1.4.1.2620.1.1.26.9.1.55',
  'fwSS-http-passed-by-URL-allow-list' => '1.3.6.1.4.1.2620.1.1.26.9.1.56',
  'fwSS-http-passed-by-URL-filter-category' => '1.3.6.1.4.1.2620.1.1.26.9.1.57',
  'fwSS-ftp' => '1.3.6.1.4.1.2620.1.1.26.9.2',
  'fwSS-ftp-pid' => '1.3.6.1.4.1.2620.1.1.26.9.2.1',
  'fwSS-ftp-proto' => '1.3.6.1.4.1.2620.1.1.26.9.2.2',
  'fwSS-ftp-port' => '1.3.6.1.4.1.2620.1.1.26.9.2.3',
  'fwSS-ftp-logical-port' => '1.3.6.1.4.1.2620.1.1.26.9.2.4',
  'fwSS-ftp-max-avail-socket' => '1.3.6.1.4.1.2620.1.1.26.9.2.5',
  'fwSS-ftp-socket-in-use-max' => '1.3.6.1.4.1.2620.1.1.26.9.2.6',
  'fwSS-ftp-socket-in-use-curr' => '1.3.6.1.4.1.2620.1.1.26.9.2.7',
  'fwSS-ftp-socket-in-use-count' => '1.3.6.1.4.1.2620.1.1.26.9.2.8',
  'fwSS-ftp-sess-max' => '1.3.6.1.4.1.2620.1.1.26.9.2.9',
  'fwSS-ftp-sess-curr' => '1.3.6.1.4.1.2620.1.1.26.9.2.10',
  'fwSS-ftp-sess-count' => '1.3.6.1.4.1.2620.1.1.26.9.2.11',
  'fwSS-ftp-auth-sess-max' => '1.3.6.1.4.1.2620.1.1.26.9.2.12',
  'fwSS-ftp-auth-sess-curr' => '1.3.6.1.4.1.2620.1.1.26.9.2.13',
  'fwSS-ftp-auth-sess-count' => '1.3.6.1.4.1.2620.1.1.26.9.2.14',
  'fwSS-ftp-accepted-sess' => '1.3.6.1.4.1.2620.1.1.26.9.2.15',
  'fwSS-ftp-rejected-sess' => '1.3.6.1.4.1.2620.1.1.26.9.2.16',
  'fwSS-ftp-auth-failures' => '1.3.6.1.4.1.2620.1.1.26.9.2.17',
  'fwSS-ftp-ops-cvp-sess-max' => '1.3.6.1.4.1.2620.1.1.26.9.2.18',
  'fwSS-ftp-ops-cvp-sess-curr' => '1.3.6.1.4.1.2620.1.1.26.9.2.19',
  'fwSS-ftp-ops-cvp-sess-count' => '1.3.6.1.4.1.2620.1.1.26.9.2.20',
  'fwSS-ftp-ops-cvp-rej-sess' => '1.3.6.1.4.1.2620.1.1.26.9.2.21',
  'fwSS-ftp-time-stamp' => '1.3.6.1.4.1.2620.1.1.26.9.2.22',
  'fwSS-ftp-is-alive' => '1.3.6.1.4.1.2620.1.1.26.9.2.23',
  'fwSS-ftp-blocked-cnt' => '1.3.6.1.4.1.2620.1.1.26.9.2.24',
  'fwSS-ftp-blocked-total' => '1.3.6.1.4.1.2620.1.1.26.9.2.25',
  'fwSS-ftp-scanned-total' => '1.3.6.1.4.1.2620.1.1.26.9.2.26',
  'fwSS-ftp-blocked-by-file-type' => '1.3.6.1.4.1.2620.1.1.26.9.2.27',
  'fwSS-ftp-blocked-by-size-limit' => '1.3.6.1.4.1.2620.1.1.26.9.2.28',
  'fwSS-ftp-blocked-by-archive-limit' => '1.3.6.1.4.1.2620.1.1.26.9.2.29',
  'fwSS-ftp-blocked-by-internal-error' => '1.3.6.1.4.1.2620.1.1.26.9.2.30',
  'fwSS-ftp-passed-cnt' => '1.3.6.1.4.1.2620.1.1.26.9.2.31',
  'fwSS-ftp-passed-by-file-type' => '1.3.6.1.4.1.2620.1.1.26.9.2.32',
  'fwSS-ftp-passed-by-size-limit' => '1.3.6.1.4.1.2620.1.1.26.9.2.33',
  'fwSS-ftp-passed-by-archive-limit' => '1.3.6.1.4.1.2620.1.1.26.9.2.34',
  'fwSS-ftp-passed-by-internal-error' => '1.3.6.1.4.1.2620.1.1.26.9.2.35',
  'fwSS-ftp-passed-total' => '1.3.6.1.4.1.2620.1.1.26.9.2.36',
  'fwSS-ftp-blocked-by-AV-settings' => '1.3.6.1.4.1.2620.1.1.26.9.2.37',
  'fwSS-ftp-passed-by-AV-settings' => '1.3.6.1.4.1.2620.1.1.26.9.2.38',
  'fwSS-telnet' => '1.3.6.1.4.1.2620.1.1.26.9.3',
  'fwSS-telnet-pid' => '1.3.6.1.4.1.2620.1.1.26.9.3.1',
  'fwSS-telnet-proto' => '1.3.6.1.4.1.2620.1.1.26.9.3.2',
  'fwSS-telnet-port' => '1.3.6.1.4.1.2620.1.1.26.9.3.3',
  'fwSS-telnet-logical-port' => '1.3.6.1.4.1.2620.1.1.26.9.3.4',
  'fwSS-telnet-max-avail-socket' => '1.3.6.1.4.1.2620.1.1.26.9.3.5',
  'fwSS-telnet-socket-in-use-max' => '1.3.6.1.4.1.2620.1.1.26.9.3.6',
  'fwSS-telnet-socket-in-use-curr' => '1.3.6.1.4.1.2620.1.1.26.9.3.7',
  'fwSS-telnet-socket-in-use-count' => '1.3.6.1.4.1.2620.1.1.26.9.3.8',
  'fwSS-telnet-sess-max' => '1.3.6.1.4.1.2620.1.1.26.9.3.9',
  'fwSS-telnet-sess-curr' => '1.3.6.1.4.1.2620.1.1.26.9.3.10',
  'fwSS-telnet-sess-count' => '1.3.6.1.4.1.2620.1.1.26.9.3.11',
  'fwSS-telnet-auth-sess-max' => '1.3.6.1.4.1.2620.1.1.26.9.3.12',
  'fwSS-telnet-auth-sess-curr' => '1.3.6.1.4.1.2620.1.1.26.9.3.13',
  'fwSS-telnet-auth-sess-count' => '1.3.6.1.4.1.2620.1.1.26.9.3.14',
  'fwSS-telnet-accepted-sess' => '1.3.6.1.4.1.2620.1.1.26.9.3.15',
  'fwSS-telnet-rejected-sess' => '1.3.6.1.4.1.2620.1.1.26.9.3.16',
  'fwSS-telnet-auth-failures' => '1.3.6.1.4.1.2620.1.1.26.9.3.17',
  'fwSS-telnet-time-stamp' => '1.3.6.1.4.1.2620.1.1.26.9.3.18',
  'fwSS-telnet-is-alive' => '1.3.6.1.4.1.2620.1.1.26.9.3.19',
  'fwSS-rlogin' => '1.3.6.1.4.1.2620.1.1.26.9.4',
  'fwSS-rlogin-pid' => '1.3.6.1.4.1.2620.1.1.26.9.4.1',
  'fwSS-rlogin-proto' => '1.3.6.1.4.1.2620.1.1.26.9.4.2',
  'fwSS-rlogin-port' => '1.3.6.1.4.1.2620.1.1.26.9.4.3',
  'fwSS-rlogin-logical-port' => '1.3.6.1.4.1.2620.1.1.26.9.4.4',
  'fwSS-rlogin-max-avail-socket' => '1.3.6.1.4.1.2620.1.1.26.9.4.5',
  'fwSS-rlogin-socket-in-use-max' => '1.3.6.1.4.1.2620.1.1.26.9.4.6',
  'fwSS-rlogin-socket-in-use-curr' => '1.3.6.1.4.1.2620.1.1.26.9.4.7',
  'fwSS-rlogin-socket-in-use-count' => '1.3.6.1.4.1.2620.1.1.26.9.4.8',
  'fwSS-rlogin-sess-max' => '1.3.6.1.4.1.2620.1.1.26.9.4.9',
  'fwSS-rlogin-sess-curr' => '1.3.6.1.4.1.2620.1.1.26.9.4.10',
  'fwSS-rlogin-sess-count' => '1.3.6.1.4.1.2620.1.1.26.9.4.11',
  'fwSS-rlogin-auth-sess-max' => '1.3.6.1.4.1.2620.1.1.26.9.4.12',
  'fwSS-rlogin-auth-sess-curr' => '1.3.6.1.4.1.2620.1.1.26.9.4.13',
  'fwSS-rlogin-auth-sess-count' => '1.3.6.1.4.1.2620.1.1.26.9.4.14',
  'fwSS-rlogin-accepted-sess' => '1.3.6.1.4.1.2620.1.1.26.9.4.15',
  'fwSS-rlogin-rejected-sess' => '1.3.6.1.4.1.2620.1.1.26.9.4.16',
  'fwSS-rlogin-auth-failures' => '1.3.6.1.4.1.2620.1.1.26.9.4.17',
  'fwSS-rlogin-time-stamp' => '1.3.6.1.4.1.2620.1.1.26.9.4.18',
  'fwSS-rlogin-is-alive' => '1.3.6.1.4.1.2620.1.1.26.9.4.19',
  'fwSS-ufp' => '1.3.6.1.4.1.2620.1.1.26.9.5',
  'fwSS-ufp-ops-ufp-sess-max' => '1.3.6.1.4.1.2620.1.1.26.9.5.1',
  'fwSS-ufp-ops-ufp-sess-curr' => '1.3.6.1.4.1.2620.1.1.26.9.5.2',
  'fwSS-ufp-ops-ufp-sess-count' => '1.3.6.1.4.1.2620.1.1.26.9.5.3',
  'fwSS-ufp-ops-ufp-rej-sess' => '1.3.6.1.4.1.2620.1.1.26.9.5.4',
  'fwSS-ufp-time-stamp' => '1.3.6.1.4.1.2620.1.1.26.9.5.5',
  'fwSS-ufp-is-alive' => '1.3.6.1.4.1.2620.1.1.26.9.5.6',
  'fwSS-smtp' => '1.3.6.1.4.1.2620.1.1.26.9.6',
  'fwSS-smtp-pid' => '1.3.6.1.4.1.2620.1.1.26.9.6.1',
  'fwSS-smtp-proto' => '1.3.6.1.4.1.2620.1.1.26.9.6.2',
  'fwSS-smtp-port' => '1.3.6.1.4.1.2620.1.1.26.9.6.3',
  'fwSS-smtp-logical-port' => '1.3.6.1.4.1.2620.1.1.26.9.6.4',
  'fwSS-smtp-max-avail-socket' => '1.3.6.1.4.1.2620.1.1.26.9.6.5',
  'fwSS-smtp-socket-in-use-max' => '1.3.6.1.4.1.2620.1.1.26.9.6.6',
  'fwSS-smtp-socket-in-use-curr' => '1.3.6.1.4.1.2620.1.1.26.9.6.7',
  'fwSS-smtp-socket-in-use-count' => '1.3.6.1.4.1.2620.1.1.26.9.6.8',
  'fwSS-smtp-sess-max' => '1.3.6.1.4.1.2620.1.1.26.9.6.9',
  'fwSS-smtp-sess-curr' => '1.3.6.1.4.1.2620.1.1.26.9.6.10',
  'fwSS-smtp-sess-count' => '1.3.6.1.4.1.2620.1.1.26.9.6.11',
  'fwSS-smtp-auth-sess-max' => '1.3.6.1.4.1.2620.1.1.26.9.6.12',
  'fwSS-smtp-auth-sess-curr' => '1.3.6.1.4.1.2620.1.1.26.9.6.13',
  'fwSS-smtp-auth-sess-count' => '1.3.6.1.4.1.2620.1.1.26.9.6.14',
  'fwSS-smtp-accepted-sess' => '1.3.6.1.4.1.2620.1.1.26.9.6.15',
  'fwSS-smtp-rejected-sess' => '1.3.6.1.4.1.2620.1.1.26.9.6.16',
  'fwSS-smtp-auth-failures' => '1.3.6.1.4.1.2620.1.1.26.9.6.17',
  'fwSS-smtp-mail-max' => '1.3.6.1.4.1.2620.1.1.26.9.6.18',
  'fwSS-smtp-mail-curr' => '1.3.6.1.4.1.2620.1.1.26.9.6.19',
  'fwSS-smtp-mail-count' => '1.3.6.1.4.1.2620.1.1.26.9.6.20',
  'fwSS-smtp-outgoing-mail-max' => '1.3.6.1.4.1.2620.1.1.26.9.6.21',
  'fwSS-smtp-outgoing-mail-curr' => '1.3.6.1.4.1.2620.1.1.26.9.6.22',
  'fwSS-smtp-outgoing-mail-count' => '1.3.6.1.4.1.2620.1.1.26.9.6.23',
  'fwSS-smtp-max-mail-on-conn' => '1.3.6.1.4.1.2620.1.1.26.9.6.24',
  'fwSS-smtp-total-mails' => '1.3.6.1.4.1.2620.1.1.26.9.6.25',
  'fwSS-smtp-time-stamp' => '1.3.6.1.4.1.2620.1.1.26.9.6.26',
  'fwSS-smtp-is-alive' => '1.3.6.1.4.1.2620.1.1.26.9.6.27',
  'fwSS-smtp-blocked-cnt' => '1.3.6.1.4.1.2620.1.1.26.9.6.28',
  'fwSS-smtp-blocked-total' => '1.3.6.1.4.1.2620.1.1.26.9.6.29',
  'fwSS-smtp-scanned-total' => '1.3.6.1.4.1.2620.1.1.26.9.6.30',
  'fwSS-smtp-blocked-by-file-type' => '1.3.6.1.4.1.2620.1.1.26.9.6.31',
  'fwSS-smtp-blocked-by-size-limit' => '1.3.6.1.4.1.2620.1.1.26.9.6.32',
  'fwSS-smtp-blocked-by-archive-limit' => '1.3.6.1.4.1.2620.1.1.26.9.6.33',
  'fwSS-smtp-blocked-by-internal-error' => '1.3.6.1.4.1.2620.1.1.26.9.6.34',
  'fwSS-smtp-passed-cnt' => '1.3.6.1.4.1.2620.1.1.26.9.6.35',
  'fwSS-smtp-passed-by-file-type' => '1.3.6.1.4.1.2620.1.1.26.9.6.36',
  'fwSS-smtp-passed-by-size-limit' => '1.3.6.1.4.1.2620.1.1.26.9.6.37',
  'fwSS-smtp-passed-by-archive-limit' => '1.3.6.1.4.1.2620.1.1.26.9.6.38',
  'fwSS-smtp-passed-by-internal-error' => '1.3.6.1.4.1.2620.1.1.26.9.6.39',
  'fwSS-smtp-passed-total' => '1.3.6.1.4.1.2620.1.1.26.9.6.40',
  'fwSS-smtp-blocked-by-AV-settings' => '1.3.6.1.4.1.2620.1.1.26.9.6.41',
  'fwSS-smtp-passed-by-AV-settings' => '1.3.6.1.4.1.2620.1.1.26.9.6.42',
  'fwSS-POP3' => '1.3.6.1.4.1.2620.1.1.26.9.7',
  'fwSS-POP3-pid' => '1.3.6.1.4.1.2620.1.1.26.9.7.1',
  'fwSS-POP3-proto' => '1.3.6.1.4.1.2620.1.1.26.9.7.2',
  'fwSS-POP3-port' => '1.3.6.1.4.1.2620.1.1.26.9.7.3',
  'fwSS-POP3-logical-port' => '1.3.6.1.4.1.2620.1.1.26.9.7.4',
  'fwSS-POP3-max-avail-socket' => '1.3.6.1.4.1.2620.1.1.26.9.7.5',
  'fwSS-POP3-socket-in-use-max' => '1.3.6.1.4.1.2620.1.1.26.9.7.6',
  'fwSS-POP3-socket-in-use-curr' => '1.3.6.1.4.1.2620.1.1.26.9.7.7',
  'fwSS-POP3-socket-in-use-count' => '1.3.6.1.4.1.2620.1.1.26.9.7.8',
  'fwSS-POP3-sess-max' => '1.3.6.1.4.1.2620.1.1.26.9.7.9',
  'fwSS-POP3-sess-curr' => '1.3.6.1.4.1.2620.1.1.26.9.7.10',
  'fwSS-POP3-sess-count' => '1.3.6.1.4.1.2620.1.1.26.9.7.11',
  'fwSS-POP3-auth-sess-max' => '1.3.6.1.4.1.2620.1.1.26.9.7.12',
  'fwSS-POP3-auth-sess-curr' => '1.3.6.1.4.1.2620.1.1.26.9.7.13',
  'fwSS-POP3-auth-sess-count' => '1.3.6.1.4.1.2620.1.1.26.9.7.14',
  'fwSS-POP3-accepted-sess' => '1.3.6.1.4.1.2620.1.1.26.9.7.15',
  'fwSS-POP3-rejected-sess' => '1.3.6.1.4.1.2620.1.1.26.9.7.16',
  'fwSS-POP3-auth-failures' => '1.3.6.1.4.1.2620.1.1.26.9.7.17',
  'fwSS-POP3-mail-max' => '1.3.6.1.4.1.2620.1.1.26.9.7.18',
  'fwSS-POP3-mail-curr' => '1.3.6.1.4.1.2620.1.1.26.9.7.19',
  'fwSS-POP3-mail-count' => '1.3.6.1.4.1.2620.1.1.26.9.7.20',
  'fwSS-POP3-outgoing-mail-max' => '1.3.6.1.4.1.2620.1.1.26.9.7.21',
  'fwSS-POP3-outgoing-mail-curr' => '1.3.6.1.4.1.2620.1.1.26.9.7.22',
  'fwSS-POP3-outgoing-mail-count' => '1.3.6.1.4.1.2620.1.1.26.9.7.23',
  'fwSS-POP3-max-mail-on-conn' => '1.3.6.1.4.1.2620.1.1.26.9.7.24',
  'fwSS-POP3-total-mails' => '1.3.6.1.4.1.2620.1.1.26.9.7.25',
  'fwSS-POP3-time-stamp' => '1.3.6.1.4.1.2620.1.1.26.9.7.26',
  'fwSS-POP3-is-alive' => '1.3.6.1.4.1.2620.1.1.26.9.7.27',
  'fwSS-POP3-blocked-cnt' => '1.3.6.1.4.1.2620.1.1.26.9.7.28',
  'fwSS-POP3-blocked-total' => '1.3.6.1.4.1.2620.1.1.26.9.7.29',
  'fwSS-POP3-scanned-total' => '1.3.6.1.4.1.2620.1.1.26.9.7.30',
  'fwSS-POP3-blocked-by-file-type' => '1.3.6.1.4.1.2620.1.1.26.9.7.31',
  'fwSS-POP3-blocked-by-size-limit' => '1.3.6.1.4.1.2620.1.1.26.9.7.32',
  'fwSS-POP3-blocked-by-archive-limit' => '1.3.6.1.4.1.2620.1.1.26.9.7.33',
  'fwSS-POP3-blocked-by-internal-error' => '1.3.6.1.4.1.2620.1.1.26.9.7.34',
  'fwSS-POP3-passed-cnt' => '1.3.6.1.4.1.2620.1.1.26.9.7.35',
  'fwSS-POP3-passed-by-file-type' => '1.3.6.1.4.1.2620.1.1.26.9.7.36',
  'fwSS-POP3-passed-by-size-limit' => '1.3.6.1.4.1.2620.1.1.26.9.7.37',
  'fwSS-POP3-passed-by-archive-limit' => '1.3.6.1.4.1.2620.1.1.26.9.7.38',
  'fwSS-POP3-passed-by-internal-error' => '1.3.6.1.4.1.2620.1.1.26.9.7.39',
  'fwSS-POP3-passed-total' => '1.3.6.1.4.1.2620.1.1.26.9.7.40',
  'fwSS-POP3-blocked-by-AV-settings' => '1.3.6.1.4.1.2620.1.1.26.9.7.41',
  'fwSS-POP3-passed-by-AV-settings' => '1.3.6.1.4.1.2620.1.1.26.9.7.42',
  'fwSS-av-total' => '1.3.6.1.4.1.2620.1.1.26.9.10',
  'fwSS-total-blocked-by-av' => '1.3.6.1.4.1.2620.1.1.26.9.10.1',
  'fwSS-total-blocked' => '1.3.6.1.4.1.2620.1.1.26.9.10.2',
  'fwSS-total-scanned' => '1.3.6.1.4.1.2620.1.1.26.9.10.3',
  'fwSS-total-blocked-by-file-type' => '1.3.6.1.4.1.2620.1.1.26.9.10.4',
  'fwSS-total-blocked-by-size-limit' => '1.3.6.1.4.1.2620.1.1.26.9.10.5',
  'fwSS-total-blocked-by-archive-limit' => '1.3.6.1.4.1.2620.1.1.26.9.10.6',
  'fwSS-total-blocked-by-interal-error' => '1.3.6.1.4.1.2620.1.1.26.9.10.7',
  'fwSS-total-passed-by-av' => '1.3.6.1.4.1.2620.1.1.26.9.10.8',
  'fwSS-total-passed-by-file-type' => '1.3.6.1.4.1.2620.1.1.26.9.10.9',
  'fwSS-total-passed-by-size-limit' => '1.3.6.1.4.1.2620.1.1.26.9.10.10',
  'fwSS-total-passed-by-archive-limit' => '1.3.6.1.4.1.2620.1.1.26.9.10.11',
  'fwSS-total-passed-by-interal-error' => '1.3.6.1.4.1.2620.1.1.26.9.10.12',
  'fwSS-total-passed' => '1.3.6.1.4.1.2620.1.1.26.9.10.13',
  'fwSS-total-blocked-by-av-settings' => '1.3.6.1.4.1.2620.1.1.26.9.10.14',
  'fwSS-total-passed-by-av-settings' => '1.3.6.1.4.1.2620.1.1.26.9.10.15',
  'fwConnectionsStat' => '1.3.6.1.4.1.2620.1.1.26.11',
  'fwConnectionsStatConnectionsTcp' => '1.3.6.1.4.1.2620.1.1.26.11.1',
  'fwConnectionsStatConnectionsUdp' => '1.3.6.1.4.1.2620.1.1.26.11.2',
  'fwConnectionsStatConnectionsIcmp' => '1.3.6.1.4.1.2620.1.1.26.11.3',
  'fwConnectionsStatConnectionsOther' => '1.3.6.1.4.1.2620.1.1.26.11.4',
  'fwConnectionsStatConnections' => '1.3.6.1.4.1.2620.1.1.26.11.5',
  'fwConnectionsStatConnectionRate' => '1.3.6.1.4.1.2620.1.1.26.11.6',
  'fwHmem64' => '1.3.6.1.4.1.2620.1.1.26.12',
  'fwHmem64-block-size' => '1.3.6.1.4.1.2620.1.1.26.12.1',
  'fwHmem64-requested-bytes' => '1.3.6.1.4.1.2620.1.1.26.12.2',
  'fwHmem64-initial-allocated-bytes' => '1.3.6.1.4.1.2620.1.1.26.12.3',
  'fwHmem64-initial-allocated-blocks' => '1.3.6.1.4.1.2620.1.1.26.12.4',
  'fwHmem64-initial-allocated-pools' => '1.3.6.1.4.1.2620.1.1.26.12.5',
  'fwHmem64-current-allocated-bytes' => '1.3.6.1.4.1.2620.1.1.26.12.6',
  'fwHmem64-current-allocated-blocks' => '1.3.6.1.4.1.2620.1.1.26.12.7',
  'fwHmem64-current-allocated-pools' => '1.3.6.1.4.1.2620.1.1.26.12.8',
  'fwHmem64-maximum-bytes' => '1.3.6.1.4.1.2620.1.1.26.12.9',
  'fwHmem64-maximum-pools' => '1.3.6.1.4.1.2620.1.1.26.12.10',
  'fwHmem64-bytes-used' => '1.3.6.1.4.1.2620.1.1.26.12.11',
  'fwHmem64-blocks-used' => '1.3.6.1.4.1.2620.1.1.26.12.12',
  'fwHmem64-bytes-unused' => '1.3.6.1.4.1.2620.1.1.26.12.13',
  'fwHmem64-blocks-unused' => '1.3.6.1.4.1.2620.1.1.26.12.14',
  'fwHmem64-bytes-peak' => '1.3.6.1.4.1.2620.1.1.26.12.15',
  'fwHmem64-blocks-peak' => '1.3.6.1.4.1.2620.1.1.26.12.16',
  'fwHmem64-bytes-internal-use' => '1.3.6.1.4.1.2620.1.1.26.12.17',
  'fwHmem64-number-of-items' => '1.3.6.1.4.1.2620.1.1.26.12.18',
  'fwHmem64-alloc-operations' => '1.3.6.1.4.1.2620.1.1.26.12.19',
  'fwHmem64-free-operations' => '1.3.6.1.4.1.2620.1.1.26.12.20',
  'fwHmem64-failed-alloc' => '1.3.6.1.4.1.2620.1.1.26.12.21',
  'fwHmem64-failed-free' => '1.3.6.1.4.1.2620.1.1.26.12.22',
  'fwNetIfTable' => '1.3.6.1.4.1.2620.1.1.27',
  'fwNetIfEntry' => '1.3.6.1.4.1.2620.1.1.27.1',
  'fwNetIfIndex' => '1.3.6.1.4.1.2620.1.1.27.1.1',
  'fwNetIfName' => '1.3.6.1.4.1.2620.1.1.27.1.2',
  'fwNetIfIPAddr' => '1.3.6.1.4.1.2620.1.1.27.1.3',
  'fwNetIfNetmask' => '1.3.6.1.4.1.2620.1.1.27.1.4',
  'fwNetIfFlags' => '1.3.6.1.4.1.2620.1.1.27.1.5',
  'fwNetIfPeerName' => '1.3.6.1.4.1.2620.1.1.27.1.6',
  'fwNetIfRemoteIp' => '1.3.6.1.4.1.2620.1.1.27.1.7',
  'fwNetIfTopology' => '1.3.6.1.4.1.2620.1.1.27.1.8',
  'fwNetIfProxyName' => '1.3.6.1.4.1.2620.1.1.27.1.9',
  'fwNetIfSlaves' => '1.3.6.1.4.1.2620.1.1.27.1.10',
  'fwNetIfPorts' => '1.3.6.1.4.1.2620.1.1.27.1.11',
  'fwNetIfIPV6Addr' => '1.3.6.1.4.1.2620.1.1.27.1.12',
  'fwNetIfIPV6AddrLen' => '1.3.6.1.4.1.2620.1.1.27.1.13',
  'fwLSConn' => '1.3.6.1.4.1.2620.1.1.30',
  'fwLSConnOverall' => '1.3.6.1.4.1.2620.1.1.30.1',
  'fwLSConnOverallDesc' => '1.3.6.1.4.1.2620.1.1.30.2',
  'fwLSConnTable' => '1.3.6.1.4.1.2620.1.1.30.3',
  'fwLSConnEntry' => '1.3.6.1.4.1.2620.1.1.30.3.1',
  'fwLSConnIndex' => '1.3.6.1.4.1.2620.1.1.30.3.1.1',
  'fwLSConnName' => '1.3.6.1.4.1.2620.1.1.30.3.1.2',
  'fwLSConnState' => '1.3.6.1.4.1.2620.1.1.30.3.1.3',
  'fwLSConnStateDesc' => '1.3.6.1.4.1.2620.1.1.30.3.1.4',
  'fwLSConnSendRate' => '1.3.6.1.4.1.2620.1.1.30.3.1.5',
  'fwLocalLoggingDesc' => '1.3.6.1.4.1.2620.1.1.30.4',
  'fwLocalLoggingStat' => '1.3.6.1.4.1.2620.1.1.30.5',
  'fwLocalLoggingWriteRate' => '1.3.6.1.4.1.2620.1.1.30.6',
  'fwLoggingHandlingRate' => '1.3.6.1.4.1.2620.1.1.30.7',
  'vpn' => '1.3.6.1.4.1.2620.1.2',
  'cpvProdName' => '1.3.6.1.4.1.2620.1.2.1',
  'cpvVerMajor' => '1.3.6.1.4.1.2620.1.2.2',
  'cpvVerMinor' => '1.3.6.1.4.1.2620.1.2.3',
  'cpvGeneral' => '1.3.6.1.4.1.2620.1.2.4',
  'cpvStatistics' => '1.3.6.1.4.1.2620.1.2.4.1',
  'cpvEncPackets' => '1.3.6.1.4.1.2620.1.2.4.1.1',
  'cpvDecPackets' => '1.3.6.1.4.1.2620.1.2.4.1.2',
  'cpvErrors' => '1.3.6.1.4.1.2620.1.2.4.2',
  'cpvErrOut' => '1.3.6.1.4.1.2620.1.2.4.2.1',
  'cpvErrIn' => '1.3.6.1.4.1.2620.1.2.4.2.2',
  'cpvErrIke' => '1.3.6.1.4.1.2620.1.2.4.2.3',
  'cpvErrPolicy' => '1.3.6.1.4.1.2620.1.2.4.2.4',
  'cpvIpsec' => '1.3.6.1.4.1.2620.1.2.5',
  'cpvSaStatistics' => '1.3.6.1.4.1.2620.1.2.5.2',
  'cpvCurrEspSAsIn' => '1.3.6.1.4.1.2620.1.2.5.2.1',
  'cpvTotalEspSAsIn' => '1.3.6.1.4.1.2620.1.2.5.2.2',
  'cpvCurrEspSAsOut' => '1.3.6.1.4.1.2620.1.2.5.2.3',
  'cpvTotalEspSAsOut' => '1.3.6.1.4.1.2620.1.2.5.2.4',
  'cpvCurrAhSAsIn' => '1.3.6.1.4.1.2620.1.2.5.2.5',
  'cpvTotalAhSAsIn' => '1.3.6.1.4.1.2620.1.2.5.2.6',
  'cpvCurrAhSAsOut' => '1.3.6.1.4.1.2620.1.2.5.2.7',
  'cpvTotalAhSAsOut' => '1.3.6.1.4.1.2620.1.2.5.2.8',
  'cpvMaxConncurEspSAsIn' => '1.3.6.1.4.1.2620.1.2.5.2.9',
  'cpvMaxConncurEspSAsOut' => '1.3.6.1.4.1.2620.1.2.5.2.10',
  'cpvMaxConncurAhSAsIn' => '1.3.6.1.4.1.2620.1.2.5.2.11',
  'cpvMaxConncurAhSAsOut' => '1.3.6.1.4.1.2620.1.2.5.2.12',
  'cpvSaErrors' => '1.3.6.1.4.1.2620.1.2.5.3',
  'cpvSaDecrErr' => '1.3.6.1.4.1.2620.1.2.5.3.1',
  'cpvSaAuthErr' => '1.3.6.1.4.1.2620.1.2.5.3.2',
  'cpvSaReplayErr' => '1.3.6.1.4.1.2620.1.2.5.3.3',
  'cpvSaPolicyErr' => '1.3.6.1.4.1.2620.1.2.5.3.4',
  'cpvSaOtherErrIn' => '1.3.6.1.4.1.2620.1.2.5.3.5',
  'cpvSaOtherErrOut' => '1.3.6.1.4.1.2620.1.2.5.3.6',
  'cpvSaUnknownSpiErr' => '1.3.6.1.4.1.2620.1.2.5.3.7',
  'cpvIpsecStatistics' => '1.3.6.1.4.1.2620.1.2.5.4',
  'cpvIpsecUdpEspEncPkts' => '1.3.6.1.4.1.2620.1.2.5.4.1',
  'cpvIpsecUdpEspDecPkts' => '1.3.6.1.4.1.2620.1.2.5.4.2',
  'cpvIpsecAhEncPkts' => '1.3.6.1.4.1.2620.1.2.5.4.3',
  'cpvIpsecAhDecPkts' => '1.3.6.1.4.1.2620.1.2.5.4.4',
  'cpvIpsecEspEncPkts' => '1.3.6.1.4.1.2620.1.2.5.4.5',
  'cpvIpsecEspDecPkts' => '1.3.6.1.4.1.2620.1.2.5.4.6',
  'cpvIpsecDecomprBytesBefore' => '1.3.6.1.4.1.2620.1.2.5.4.7',
  'cpvIpsecDecomprBytesAfter' => '1.3.6.1.4.1.2620.1.2.5.4.8',
  'cpvIpsecDecomprOverhead' => '1.3.6.1.4.1.2620.1.2.5.4.9',
  'cpvIpsecDecomprPkts' => '1.3.6.1.4.1.2620.1.2.5.4.10',
  'cpvIpsecDecomprErr' => '1.3.6.1.4.1.2620.1.2.5.4.11',
  'cpvIpsecComprBytesBefore' => '1.3.6.1.4.1.2620.1.2.5.4.12',
  'cpvIpsecComprBytesAfter' => '1.3.6.1.4.1.2620.1.2.5.4.13',
  'cpvIpsecComprOverhead' => '1.3.6.1.4.1.2620.1.2.5.4.14',
  'cpvIpsecNonCompressibleBytes' => '1.3.6.1.4.1.2620.1.2.5.4.15',
  'cpvIpsecCompressiblePkts' => '1.3.6.1.4.1.2620.1.2.5.4.16',
  'cpvIpsecNonCompressiblePkts' => '1.3.6.1.4.1.2620.1.2.5.4.17',
  'cpvIpsecComprErrors' => '1.3.6.1.4.1.2620.1.2.5.4.18',
  'cpvIpsecEspEncBytes' => '1.3.6.1.4.1.2620.1.2.5.4.19',
  'cpvIpsecEspDecBytes' => '1.3.6.1.4.1.2620.1.2.5.4.20',
  'cpvFwz' => '1.3.6.1.4.1.2620.1.2.6',
  'cpvFwzStatistics' => '1.3.6.1.4.1.2620.1.2.6.1',
  'cpvFwzEncapsEncPkts' => '1.3.6.1.4.1.2620.1.2.6.1.1',
  'cpvFwzEncapsDecPkts' => '1.3.6.1.4.1.2620.1.2.6.1.2',
  'cpvFwzEncPkts' => '1.3.6.1.4.1.2620.1.2.6.1.3',
  'cpvFwzDecPkts' => '1.3.6.1.4.1.2620.1.2.6.1.4',
  'cpvFwzErrors' => '1.3.6.1.4.1.2620.1.2.6.2',
  'cpvFwzEncapsEncErrs' => '1.3.6.1.4.1.2620.1.2.6.2.1',
  'cpvFwzEncapsDecErrs' => '1.3.6.1.4.1.2620.1.2.6.2.2',
  'cpvFwzEncErrs' => '1.3.6.1.4.1.2620.1.2.6.2.3',
  'cpvFwzDecErrs' => '1.3.6.1.4.1.2620.1.2.6.2.4',
  'cpvAccelerator' => '1.3.6.1.4.1.2620.1.2.8',
  'cpvHwAccelGeneral' => '1.3.6.1.4.1.2620.1.2.8.1',
  'cpvHwAccelVendor' => '1.3.6.1.4.1.2620.1.2.8.1.1',
  'cpvHwAccelStatus' => '1.3.6.1.4.1.2620.1.2.8.1.2',
  'cpvHwAccelDriverMajorVer' => '1.3.6.1.4.1.2620.1.2.8.1.3',
  'cpvHwAccelDriverMinorVer' => '1.3.6.1.4.1.2620.1.2.8.1.4',
  'cpvHwAccelStatistics' => '1.3.6.1.4.1.2620.1.2.8.2',
  'cpvHwAccelEspEncPkts' => '1.3.6.1.4.1.2620.1.2.8.2.1',
  'cpvHwAccelEspDecPkts' => '1.3.6.1.4.1.2620.1.2.8.2.2',
  'cpvHwAccelEspEncBytes' => '1.3.6.1.4.1.2620.1.2.8.2.3',
  'cpvHwAccelEspDecBytes' => '1.3.6.1.4.1.2620.1.2.8.2.4',
  'cpvHwAccelAhEncPkts' => '1.3.6.1.4.1.2620.1.2.8.2.5',
  'cpvHwAccelAhDecPkts' => '1.3.6.1.4.1.2620.1.2.8.2.6',
  'cpvHwAccelAhEncBytes' => '1.3.6.1.4.1.2620.1.2.8.2.7',
  'cpvHwAccelAhDecBytes' => '1.3.6.1.4.1.2620.1.2.8.2.8',
  'cpvIKE' => '1.3.6.1.4.1.2620.1.2.9',
  'cpvIKEglobals' => '1.3.6.1.4.1.2620.1.2.9.1',
  'cpvIKECurrSAs' => '1.3.6.1.4.1.2620.1.2.9.1.1',
  'cpvIKECurrInitSAs' => '1.3.6.1.4.1.2620.1.2.9.1.2',
  'cpvIKECurrRespSAs' => '1.3.6.1.4.1.2620.1.2.9.1.3',
  'cpvIKETotalSAs' => '1.3.6.1.4.1.2620.1.2.9.1.4',
  'cpvIKETotalInitSAs' => '1.3.6.1.4.1.2620.1.2.9.1.5',
  'cpvIKETotalRespSAs' => '1.3.6.1.4.1.2620.1.2.9.1.6',
  'cpvIKETotalSAsAttempts' => '1.3.6.1.4.1.2620.1.2.9.1.7',
  'cpvIKETotalSAsInitAttempts' => '1.3.6.1.4.1.2620.1.2.9.1.8',
  'cpvIKETotalSAsRespAttempts' => '1.3.6.1.4.1.2620.1.2.9.1.9',
  'cpvIKEMaxConncurSAs' => '1.3.6.1.4.1.2620.1.2.9.1.10',
  'cpvIKEMaxConncurInitSAs' => '1.3.6.1.4.1.2620.1.2.9.1.11',
  'cpvIKEMaxConncurRespSAs' => '1.3.6.1.4.1.2620.1.2.9.1.12',
  'cpvIKEerrors' => '1.3.6.1.4.1.2620.1.2.9.2',
  'cpvIKETotalFailuresInit' => '1.3.6.1.4.1.2620.1.2.9.2.1',
  'cpvIKENoResp' => '1.3.6.1.4.1.2620.1.2.9.2.2',
  'cpvIKETotalFailuresResp' => '1.3.6.1.4.1.2620.1.2.9.2.3',
  'cpvIPsec' => '1.3.6.1.4.1.2620.1.2.10',
  'cpvIPsecNIC' => '1.3.6.1.4.1.2620.1.2.10.1',
  'cpvIPsecNICsNum' => '1.3.6.1.4.1.2620.1.2.10.1.1',
  'cpvIPsecNICTotalDownLoadedSAs' => '1.3.6.1.4.1.2620.1.2.10.1.2',
  'cpvIPsecNICCurrDownLoadedSAs' => '1.3.6.1.4.1.2620.1.2.10.1.3',
  'cpvIPsecNICDecrBytes' => '1.3.6.1.4.1.2620.1.2.10.1.4',
  'cpvIPsecNICEncrBytes' => '1.3.6.1.4.1.2620.1.2.10.1.5',
  'cpvIPsecNICDecrPackets' => '1.3.6.1.4.1.2620.1.2.10.1.6',
  'cpvIPsecNICEncrPackets' => '1.3.6.1.4.1.2620.1.2.10.1.7',
  'fg' => '1.3.6.1.4.1.2620.1.3',
  'fgProdName' => '1.3.6.1.4.1.2620.1.3.1',
  'fgVerMajor' => '1.3.6.1.4.1.2620.1.3.2',
  'fgVerMinor' => '1.3.6.1.4.1.2620.1.3.3',
  'fgVersionString' => '1.3.6.1.4.1.2620.1.3.4',
  'fgModuleKernelBuild' => '1.3.6.1.4.1.2620.1.3.5',
  'fgStrPolicyName' => '1.3.6.1.4.1.2620.1.3.6',
  'fgInstallTime' => '1.3.6.1.4.1.2620.1.3.7',
  'fgNumInterfaces' => '1.3.6.1.4.1.2620.1.3.8',
  'fgIfTable' => '1.3.6.1.4.1.2620.1.3.9',
  'fgIfEntry' => '1.3.6.1.4.1.2620.1.3.9.1',
  'fgIfIndex' => '1.3.6.1.4.1.2620.1.3.9.1.1',
  'fgIfName' => '1.3.6.1.4.1.2620.1.3.9.1.2',
  'fgPolicyName' => '1.3.6.1.4.1.2620.1.3.9.1.3',
  'fgRateLimitIn' => '1.3.6.1.4.1.2620.1.3.9.1.4',
  'fgRateLimitOut' => '1.3.6.1.4.1.2620.1.3.9.1.5',
  'fgAvrRateIn' => '1.3.6.1.4.1.2620.1.3.9.1.6',
  'fgAvrRateOut' => '1.3.6.1.4.1.2620.1.3.9.1.7',
  'fgRetransPcktsIn' => '1.3.6.1.4.1.2620.1.3.9.1.8',
  'fgRetransPcktsOut' => '1.3.6.1.4.1.2620.1.3.9.1.9',
  'fgPendPcktsIn' => '1.3.6.1.4.1.2620.1.3.9.1.10',
  'fgPendPcktsOut' => '1.3.6.1.4.1.2620.1.3.9.1.11',
  'fgPendBytesIn' => '1.3.6.1.4.1.2620.1.3.9.1.12',
  'fgPendBytesOut' => '1.3.6.1.4.1.2620.1.3.9.1.13',
  'fgNumConnIn' => '1.3.6.1.4.1.2620.1.3.9.1.14',
  'fgNumConnOut' => '1.3.6.1.4.1.2620.1.3.9.1.15',
  'ha' => '1.3.6.1.4.1.2620.1.5',
  'haProdName' => '1.3.6.1.4.1.2620.1.5.1',
  'haInstalled' => '1.3.6.1.4.1.2620.1.5.2',
  'haVerMajor' => '1.3.6.1.4.1.2620.1.5.3',
  'haVerMinor' => '1.3.6.1.4.1.2620.1.5.4',
  'haStarted' => '1.3.6.1.4.1.2620.1.5.5',
  'haState' => '1.3.6.1.4.1.2620.1.5.6',
  'haBlockState' => '1.3.6.1.4.1.2620.1.5.7',
  'haIdentifier' => '1.3.6.1.4.1.2620.1.5.8',
  'haProtoVersion' => '1.3.6.1.4.1.2620.1.5.10',
  'haWorkMode' => '1.3.6.1.4.1.2620.1.5.11',
  'haIfTable' => '1.3.6.1.4.1.2620.1.5.12',
  'haIfEntry' => '1.3.6.1.4.1.2620.1.5.12.1',
  'haIfIndex' => '1.3.6.1.4.1.2620.1.5.12.1.1',
  'haIfName' => '1.3.6.1.4.1.2620.1.5.12.1.2',
  'haIP' => '1.3.6.1.4.1.2620.1.5.12.1.3',
  'haStatus' => '1.3.6.1.4.1.2620.1.5.12.1.4',
  'haVerified' => '1.3.6.1.4.1.2620.1.5.12.1.5',
  'haTrusted' => '1.3.6.1.4.1.2620.1.5.12.1.6',
  'haShared' => '1.3.6.1.4.1.2620.1.5.12.1.7',
  'haProblemTable' => '1.3.6.1.4.1.2620.1.5.13',
  'haProblemEntry' => '1.3.6.1.4.1.2620.1.5.13.1',
  'haProblemIndex' => '1.3.6.1.4.1.2620.1.5.13.1.1',
  'haProblemName' => '1.3.6.1.4.1.2620.1.5.13.1.2',
  'haProblemStatus' => '1.3.6.1.4.1.2620.1.5.13.1.3',
  'haProblemPriority' => '1.3.6.1.4.1.2620.1.5.13.1.4',
  'haProblemVerified' => '1.3.6.1.4.1.2620.1.5.13.1.5',
  'haProblemDescr' => '1.3.6.1.4.1.2620.1.5.13.1.6',
  'haVersionSting' => '1.3.6.1.4.1.2620.1.5.14',
  'haClusterIpTable' => '1.3.6.1.4.1.2620.1.5.15',
  'haClusterIpEntry' => '1.3.6.1.4.1.2620.1.5.15.1',
  'haClusterIpIndex' => '1.3.6.1.4.1.2620.1.5.15.1.1',
  'haClusterIpIfName' => '1.3.6.1.4.1.2620.1.5.15.1.2',
  'haClusterIpAddr' => '1.3.6.1.4.1.2620.1.5.15.1.3',
  'haClusterIpNetMask' => '1.3.6.1.4.1.2620.1.5.15.1.4',
  'haClusterIpMemberNet' => '1.3.6.1.4.1.2620.1.5.15.1.5',
  'haClusterIpMemberNetMask' => '1.3.6.1.4.1.2620.1.5.15.1.6',
  'haClusterSyncTable' => '1.3.6.1.4.1.2620.1.5.16',
  'haClusterSyncEntry' => '1.3.6.1.4.1.2620.1.5.16.1',
  'haClusterSyncIndex' => '1.3.6.1.4.1.2620.1.5.16.1.1',
  'haClusterSyncName' => '1.3.6.1.4.1.2620.1.5.16.1.2',
  'haClusterSyncAddr' => '1.3.6.1.4.1.2620.1.5.16.1.3',
  'haClusterSyncNetMask' => '1.3.6.1.4.1.2620.1.5.16.1.4',
  'haStatCode' => '1.3.6.1.4.1.2620.1.5.101',
  'haStatShort' => '1.3.6.1.4.1.2620.1.5.102',
  'haStatLong' => '1.3.6.1.4.1.2620.1.5.103',
  'haServicePack' => '1.3.6.1.4.1.2620.1.5.999',
  'svn' => '1.3.6.1.4.1.2620.1.6',
  'svnProdName' => '1.3.6.1.4.1.2620.1.6.1',
  'svnProdVerMajor' => '1.3.6.1.4.1.2620.1.6.2',
  'svnProdVerMinor' => '1.3.6.1.4.1.2620.1.6.3',
  'svnInfo' => '1.3.6.1.4.1.2620.1.6.4',
  'svnVersion' => '1.3.6.1.4.1.2620.1.6.4.1',
  'svnBuild' => '1.3.6.1.4.1.2620.1.6.4.2',
  'svnOSInfo' => '1.3.6.1.4.1.2620.1.6.5',
  'osName' => '1.3.6.1.4.1.2620.1.6.5.1',
  'osMajorVer' => '1.3.6.1.4.1.2620.1.6.5.2',
  'osMinorVer' => '1.3.6.1.4.1.2620.1.6.5.3',
  'osBuildNum' => '1.3.6.1.4.1.2620.1.6.5.4',
  'osSPmajor' => '1.3.6.1.4.1.2620.1.6.5.5',
  'osSPminor' => '1.3.6.1.4.1.2620.1.6.5.6',
  'osVersionLevel' => '1.3.6.1.4.1.2620.1.6.5.7',
  'routingTable' => '1.3.6.1.4.1.2620.1.6.6',
  'routingEntry' => '1.3.6.1.4.1.2620.1.6.6.1',
  'routingIndex' => '1.3.6.1.4.1.2620.1.6.6.1.1',
  'routingDest' => '1.3.6.1.4.1.2620.1.6.6.1.2',
  'routingMask' => '1.3.6.1.4.1.2620.1.6.6.1.3',
  'routingGatweway' => '1.3.6.1.4.1.2620.1.6.6.1.4',
  'routingIntrfName' => '1.3.6.1.4.1.2620.1.6.6.1.5',
  'svnPerf' => '1.3.6.1.4.1.2620.1.6.7',
  'svnMem' => '1.3.6.1.4.1.2620.1.6.7.1',
  'memTotalVirtual' => '1.3.6.1.4.1.2620.1.6.7.1.1',
  'memActiveVirtual' => '1.3.6.1.4.1.2620.1.6.7.1.2',
  'memTotalReal' => '1.3.6.1.4.1.2620.1.6.7.1.3',
  'memActiveReal' => '1.3.6.1.4.1.2620.1.6.7.1.4',
  'memFreeReal' => '1.3.6.1.4.1.2620.1.6.7.1.5',
  'memSwapsSec' => '1.3.6.1.4.1.2620.1.6.7.1.6',
  'memDiskTransfers' => '1.3.6.1.4.1.2620.1.6.7.1.7',
  'svnProc' => '1.3.6.1.4.1.2620.1.6.7.2',
  'procUsrTime' => '1.3.6.1.4.1.2620.1.6.7.2.1',
  'procSysTime' => '1.3.6.1.4.1.2620.1.6.7.2.2',
  'procIdleTime' => '1.3.6.1.4.1.2620.1.6.7.2.3',
  'procUsage' => '1.3.6.1.4.1.2620.1.6.7.2.4',
  'procQueue' => '1.3.6.1.4.1.2620.1.6.7.2.5',
  'procInterrupts' => '1.3.6.1.4.1.2620.1.6.7.2.6',
  'procNum' => '1.3.6.1.4.1.2620.1.6.7.2.7',
  'svnDisk' => '1.3.6.1.4.1.2620.1.6.7.3',
  'diskTime' => '1.3.6.1.4.1.2620.1.6.7.3.1',
  'diskQueue' => '1.3.6.1.4.1.2620.1.6.7.3.2',
  'diskPercent' => '1.3.6.1.4.1.2620.1.6.7.3.3',
  'diskFreeTotal' => '1.3.6.1.4.1.2620.1.6.7.3.4',
  'diskFreeAvail' => '1.3.6.1.4.1.2620.1.6.7.3.5',
  'diskTotal' => '1.3.6.1.4.1.2620.1.6.7.3.6',
  'svnMem64' => '1.3.6.1.4.1.2620.1.6.7.4',
  'memTotalVirtual64' => '1.3.6.1.4.1.2620.1.6.7.4.1',
  'memActiveVirtual64' => '1.3.6.1.4.1.2620.1.6.7.4.2',
  'memTotalReal64' => '1.3.6.1.4.1.2620.1.6.7.4.3',
  'memActiveReal64' => '1.3.6.1.4.1.2620.1.6.7.4.4',
  'memFreeReal64' => '1.3.6.1.4.1.2620.1.6.7.4.5',
  'memSwapsSec64' => '1.3.6.1.4.1.2620.1.6.7.4.6',
  'memDiskTransfers64' => '1.3.6.1.4.1.2620.1.6.7.4.7',
  'multiProcTable' => '1.3.6.1.4.1.2620.1.6.7.5',
  'multiProcEntry' => '1.3.6.1.4.1.2620.1.6.7.5.1',
  'multiProcIndex' => '1.3.6.1.4.1.2620.1.6.7.5.1.1',
  'multiProcUserTime' => '1.3.6.1.4.1.2620.1.6.7.5.1.2',
  'multiProcSystemTime' => '1.3.6.1.4.1.2620.1.6.7.5.1.3',
  'multiProcIdleTime' => '1.3.6.1.4.1.2620.1.6.7.5.1.4',
  'multiProcUsage' => '1.3.6.1.4.1.2620.1.6.7.5.1.5',
  'multiProcRunQueue' => '1.3.6.1.4.1.2620.1.6.7.5.1.6',
  'multiProcInterrupts' => '1.3.6.1.4.1.2620.1.6.7.5.1.7',
  'multiDiskTable' => '1.3.6.1.4.1.2620.1.6.7.6',
  'multiDiskEntry' => '1.3.6.1.4.1.2620.1.6.7.6.1',
  'multiDiskIndex' => '1.3.6.1.4.1.2620.1.6.7.6.1.1',
  'multiDiskName' => '1.3.6.1.4.1.2620.1.6.7.6.1.2',
  'multiDiskSize' => '1.3.6.1.4.1.2620.1.6.7.6.1.3',
  'multiDiskUsed' => '1.3.6.1.4.1.2620.1.6.7.6.1.4',
  'multiDiskFreeTotalBytes' => '1.3.6.1.4.1.2620.1.6.7.6.1.5',
  'multiDiskFreeTotalPercent' => '1.3.6.1.4.1.2620.1.6.7.6.1.6',
  'multiDiskFreeAvailableBytes' => '1.3.6.1.4.1.2620.1.6.7.6.1.7',
  'multiDiskFreeAvailablePercent' => '1.3.6.1.4.1.2620.1.6.7.6.1.8',
  'raidInfo' => '1.3.6.1.4.1.2620.1.6.7.7',
  'raidVolumeTable' => '1.3.6.1.4.1.2620.1.6.7.7.1',
  'raidVolumeEntry' => '1.3.6.1.4.1.2620.1.6.7.7.1.1',
  'raidVolumeIndex' => '1.3.6.1.4.1.2620.1.6.7.7.1.1.1',
  'raidVolumeID' => '1.3.6.1.4.1.2620.1.6.7.7.1.1.2',
  'raidVolumeType' => '1.3.6.1.4.1.2620.1.6.7.7.1.1.3',
  'numOfDisksOnRaid' => '1.3.6.1.4.1.2620.1.6.7.7.1.1.4',
  'raidVolumeMaxLBA' => '1.3.6.1.4.1.2620.1.6.7.7.1.1.5',
  'raidVolumeState' => '1.3.6.1.4.1.2620.1.6.7.7.1.1.6',
  'raidVolumeStateDefinition' => {
    0 => 'optimal',
    1 => 'degraded',
    2 => 'failed',
  },
  'raidVolumeFlags' => '1.3.6.1.4.1.2620.1.6.7.7.1.1.7',
  'raidVolumeSize' => '1.3.6.1.4.1.2620.1.6.7.7.1.1.8',
  'raidDiskTable' => '1.3.6.1.4.1.2620.1.6.7.7.2',
  'raidDiskEntry' => '1.3.6.1.4.1.2620.1.6.7.7.2.1',
  'raidDiskIndex' => '1.3.6.1.4.1.2620.1.6.7.7.2.1.1',
  'raidDiskVolumeID' => '1.3.6.1.4.1.2620.1.6.7.7.2.1.2',
  'raidDiskID' => '1.3.6.1.4.1.2620.1.6.7.7.2.1.3',
  'raidDiskNumber' => '1.3.6.1.4.1.2620.1.6.7.7.2.1.4',
  'raidDiskVendor' => '1.3.6.1.4.1.2620.1.6.7.7.2.1.5',
  'raidDiskProductID' => '1.3.6.1.4.1.2620.1.6.7.7.2.1.6',
  'raidDiskRevision' => '1.3.6.1.4.1.2620.1.6.7.7.2.1.7',
  'raidDiskMaxLBA' => '1.3.6.1.4.1.2620.1.6.7.7.2.1.8',
  'raidDiskState' => '1.3.6.1.4.1.2620.1.6.7.7.2.1.9',
  'raidDiskStateDefinition' => {
    0 => 'online',
    1 => 'missing',
    2 => 'not_compatible',
    3 => 'disc_failed',
    4 => 'initializing',
    5 => 'offline_requested',
    6 => 'failed_requested',
    7 => 'unconfigured_good_spun_up',
    8 => 'unconfigured_good_spun_down',
    9 => 'unconfigured_bad',
    10 => 'hotspare',
    11 => 'drive_offline',
    12 => 'rebuild',
    13 => 'failed',
    15 => 'copyback',
    255 => 'rebuild',
  },
  'raidDiskFlags' => '1.3.6.1.4.1.2620.1.6.7.7.2.1.10',
  'raidDiskSyncState' => '1.3.6.1.4.1.2620.1.6.7.7.2.1.11',
  'raidDiskSize' => '1.3.6.1.4.1.2620.1.6.7.7.2.1.12',
  'sensorInfo' => '1.3.6.1.4.1.2620.1.6.7.8',
  'tempertureSensorTable' => '1.3.6.1.4.1.2620.1.6.7.8.1',
  'tempertureSensorEntry' => '1.3.6.1.4.1.2620.1.6.7.8.1.1',
  'tempertureSensorIndex' => '1.3.6.1.4.1.2620.1.6.7.8.1.1.1',
  'tempertureSensorName' => '1.3.6.1.4.1.2620.1.6.7.8.1.1.2',
  'tempertureSensorValue' => '1.3.6.1.4.1.2620.1.6.7.8.1.1.3',
  'tempertureSensorUnit' => '1.3.6.1.4.1.2620.1.6.7.8.1.1.4',
  'tempertureSensorType' => '1.3.6.1.4.1.2620.1.6.7.8.1.1.5',
  'tempertureSensorStatus' => '1.3.6.1.4.1.2620.1.6.7.8.1.1.6',
  'tempertureSensorStatusDefinition' => {
    0 => 'normal', # In normal range
    1 => 'abnormal', # Out of normal range
    2 => 'unknown', # Reading error
  },
  'fanSpeedSensorTable' => '1.3.6.1.4.1.2620.1.6.7.8.2',
  'fanSpeedSensorEntry' => '1.3.6.1.4.1.2620.1.6.7.8.2.1',
  'fanSpeedSensorIndex' => '1.3.6.1.4.1.2620.1.6.7.8.2.1.1',
  'fanSpeedSensorName' => '1.3.6.1.4.1.2620.1.6.7.8.2.1.2',
  'fanSpeedSensorValue' => '1.3.6.1.4.1.2620.1.6.7.8.2.1.3',
  'fanSpeedSensorUnit' => '1.3.6.1.4.1.2620.1.6.7.8.2.1.4',
  'fanSpeedSensorType' => '1.3.6.1.4.1.2620.1.6.7.8.2.1.5',
  'fanSpeedSensorStatus' => '1.3.6.1.4.1.2620.1.6.7.8.2.1.6',
  'fanSpeedSensorStatusDefinition' => {
    0 => 'normal',
    1 => 'abnormal',
    2 => 'unknown',
  },
  'voltageSensorTable' => '1.3.6.1.4.1.2620.1.6.7.8.3',
  'voltageSensorEntry' => '1.3.6.1.4.1.2620.1.6.7.8.3.1',
  'voltageSensorIndex' => '1.3.6.1.4.1.2620.1.6.7.8.3.1.1',
  'voltageSensorName' => '1.3.6.1.4.1.2620.1.6.7.8.3.1.2',
  'voltageSensorValue' => '1.3.6.1.4.1.2620.1.6.7.8.3.1.3',
  'voltageSensorUnit' => '1.3.6.1.4.1.2620.1.6.7.8.3.1.4',
  'voltageSensorType' => '1.3.6.1.4.1.2620.1.6.7.8.3.1.5',
  'voltageSensorStatus' => '1.3.6.1.4.1.2620.1.6.7.8.3.1.6',
  'voltageSensorStatusDefinition' => {
    0 => 'normal',
    1 => 'abnormal',
    2 => 'unknown',
  },
  'powerSupplyInfo' => '1.3.6.1.4.1.2620.1.6.7.9',
  'powerSupplyTable' => '1.3.6.1.4.1.2620.1.6.7.9.1',
  'powerSupplyEntry' => '1.3.6.1.4.1.2620.1.6.7.9.1.1',
  'powerSupplyIndex' => '1.3.6.1.4.1.2620.1.6.7.9.1.1.1',
  'powerSupplyStatus' => '1.3.6.1.4.1.2620.1.6.7.9.1.1.2',
  'svnSysTime' => '1.3.6.1.4.1.2620.1.6.8',
  'svnRoutingModify' => '1.3.6.1.4.1.2620.1.6.9',
  'svnRouteModDest' => '1.3.6.1.4.1.2620.1.6.9.2',
  'svnRouteModMask' => '1.3.6.1.4.1.2620.1.6.9.3',
  'svnRouteModGateway' => '1.3.6.1.4.1.2620.1.6.9.4',
  'svnRouteModIfIndex' => '1.3.6.1.4.1.2620.1.6.9.5',
  'svnRouteModIfName' => '1.3.6.1.4.1.2620.1.6.9.6',
  'svnRouteModAction' => '1.3.6.1.4.1.2620.1.6.9.10',
  'svnUTCTimeOffset' => '1.3.6.1.4.1.2620.1.6.10',
  'svnLogDaemon' => '1.3.6.1.4.1.2620.1.6.11',
  'svnLogDStat' => '1.3.6.1.4.1.2620.1.6.11.1',
  'svnSysStartTime' => '1.3.6.1.4.1.2620.1.6.12',
  'svnSysUniqId' => '1.3.6.1.4.1.2620.1.6.13',
  'svnWebUIPort' => '1.3.6.1.4.1.2620.1.6.15',
  'svnApplianceInfo' => '1.3.6.1.4.1.2620.1.6.16',
  'svnApplianceSerialNumber' => '1.3.6.1.4.1.2620.1.6.16.3',
  'svnApplianceProductName' => '1.3.6.1.4.1.2620.1.6.16.7',
  'svnApplianceManufacturer' => '1.3.6.1.4.1.2620.1.6.16.9',
  'svnApplianceSeriesString' => '1.3.6.1.4.1.2620.1.6.16.10',
  'svnLicensing' => '1.3.6.1.4.1.2620.1.6.18',
  'licensingTable' => '1.3.6.1.4.1.2620.1.6.18.1',
  'licensingEntry' => '1.3.6.1.4.1.2620.1.6.18.1.1',
  'licensingIndex' => '1.3.6.1.4.1.2620.1.6.18.1.1.1',
  'licensingID' => '1.3.6.1.4.1.2620.1.6.18.1.1.2',
  'licensingBladeName' => '1.3.6.1.4.1.2620.1.6.18.1.1.3',
  'licensingState' => '1.3.6.1.4.1.2620.1.6.18.1.1.4',
  'licensingExpirationDate' => '1.3.6.1.4.1.2620.1.6.18.1.1.5',
  'licensingImpact' => '1.3.6.1.4.1.2620.1.6.18.1.1.6',
  'licensingBladeActive' => '1.3.6.1.4.1.2620.1.6.18.1.1.7',
  'licensingTotalQuota' => '1.3.6.1.4.1.2620.1.6.18.1.1.8',
  'licensingUsedQuota' => '1.3.6.1.4.1.2620.1.6.18.1.1.9',
  'licensingAssetInfo' => '1.3.6.1.4.1.2620.1.6.18.2',
  'licensingAssetAccountId' => '1.3.6.1.4.1.2620.1.6.18.2.1',
  'licensingAssetPackageDescription' => '1.3.6.1.4.1.2620.1.6.18.2.2',
  'licensingAssetContainerCK' => '1.3.6.1.4.1.2620.1.6.18.2.3',
  'licensingAssetContainerSKU' => '1.3.6.1.4.1.2620.1.6.18.2.4',
  'licensingAssetSupportLevel' => '1.3.6.1.4.1.2620.1.6.18.2.5',
  'licensingAssetSupportExpiration' => '1.3.6.1.4.1.2620.1.6.18.2.6',
  'licensingAssetActivationStatus' => '1.3.6.1.4.1.2620.1.6.18.2.7',
  'svnConnectivity' => '1.3.6.1.4.1.2620.1.6.19',
  'svnUpdatesInfo' => '1.3.6.1.4.1.2620.1.6.20',
  'svnUpdatesInfoBuild' => '1.3.6.1.4.1.2620.1.6.20.1',
  'svnUpdatesInfoStatus' => '1.3.6.1.4.1.2620.1.6.20.2',
  'svnUpdatesInfoConnection' => '1.3.6.1.4.1.2620.1.6.20.3',
  'svnUpdatesInfoAvailablePackages' => '1.3.6.1.4.1.2620.1.6.20.4',
  'svnUpdatesInfoAvailableRecommended' => '1.3.6.1.4.1.2620.1.6.20.5',
  'svnUpdatesInfoAvailableHotfixes' => '1.3.6.1.4.1.2620.1.6.20.6',
  'updatesInstalledTable' => '1.3.6.1.4.1.2620.1.6.20.7',
  'updatesInstalledEntry' => '1.3.6.1.4.1.2620.1.6.20.7.1',
  'updatesInstalledIndex' => '1.3.6.1.4.1.2620.1.6.20.7.1.1',
  'updatesInstalledName' => '1.3.6.1.4.1.2620.1.6.20.7.1.2',
  'updatesInstalledType' => '1.3.6.1.4.1.2620.1.6.20.7.1.3',
  'updatesRecommendedTable' => '1.3.6.1.4.1.2620.1.6.20.8',
  'updatesRecommendedEntry' => '1.3.6.1.4.1.2620.1.6.20.8.1',
  'updatesRecommendedIndex' => '1.3.6.1.4.1.2620.1.6.20.8.1.1',
  'updatesRecommendedName' => '1.3.6.1.4.1.2620.1.6.20.8.1.2',
  'updatesRecommendedType' => '1.3.6.1.4.1.2620.1.6.20.8.1.3',
  'updatesRecommendedStatus' => '1.3.6.1.4.1.2620.1.6.20.8.1.4',
  'svnNetStat' => '1.3.6.1.4.1.2620.1.6.50',
  'svnNetIfTable' => '1.3.6.1.4.1.2620.1.6.50.1',
  'svnNetIfTableEntry' => '1.3.6.1.4.1.2620.1.6.50.1.1',
  'svnNetIfIndex' => '1.3.6.1.4.1.2620.1.6.50.1.1.1',
  'svnNetIfVsid' => '1.3.6.1.4.1.2620.1.6.50.1.1.2',
  'svnNetIfName' => '1.3.6.1.4.1.2620.1.6.50.1.1.3',
  'svnNetIfAddress' => '1.3.6.1.4.1.2620.1.6.50.1.1.4',
  'svnNetIfMask' => '1.3.6.1.4.1.2620.1.6.50.1.1.5',
  'svnNetIfMTU' => '1.3.6.1.4.1.2620.1.6.50.1.1.6',
  'svnNetIfState' => '1.3.6.1.4.1.2620.1.6.50.1.1.7',
  'svnNetIfMAC' => '1.3.6.1.4.1.2620.1.6.50.1.1.8',
  'svnNetIfDescription' => '1.3.6.1.4.1.2620.1.6.50.1.1.9',
  'svnNetIfOperState' => '1.3.6.1.4.1.2620.1.6.50.1.1.10',
  'vsRoutingTable' => '1.3.6.1.4.1.2620.1.6.51',
  'vsRoutingEntry' => '1.3.6.1.4.1.2620.1.6.51.1',
  'vsRoutingIndex' => '1.3.6.1.4.1.2620.1.6.51.1.1',
  'vsRoutingDest' => '1.3.6.1.4.1.2620.1.6.51.1.2',
  'vsRoutingMask' => '1.3.6.1.4.1.2620.1.6.51.1.3',
  'vsRoutingGateway' => '1.3.6.1.4.1.2620.1.6.51.1.4',
  'vsRoutingIntrfName' => '1.3.6.1.4.1.2620.1.6.51.1.5',
  'vsRoutingVsId' => '1.3.6.1.4.1.2620.1.6.51.1.6',
  'svnStatCode' => '1.3.6.1.4.1.2620.1.6.101',
  'svnStatShortDescr' => '1.3.6.1.4.1.2620.1.6.102',
  'svnStatLongDescr' => '1.3.6.1.4.1.2620.1.6.103',
  'svnPlatformInfo' => '1.3.6.1.4.1.2620.1.6.123',
  'supportedPlatforms' => '1.3.6.1.4.1.2620.1.6.123.1',
  'checkPointUTM-1450' => '1.3.6.1.4.1.2620.1.6.123.1.1',
  'checkPointUTM-11050' => '1.3.6.1.4.1.2620.1.6.123.1.2',
  'checkPointUTM-12050' => '1.3.6.1.4.1.2620.1.6.123.1.3',
  'checkPointUTM-1130' => '1.3.6.1.4.1.2620.1.6.123.1.4',
  'checkPointUTM-1270' => '1.3.6.1.4.1.2620.1.6.123.1.5',
  'checkPointUTM-1570' => '1.3.6.1.4.1.2620.1.6.123.1.6',
  'checkPointUTM-11070' => '1.3.6.1.4.1.2620.1.6.123.1.7',
  'checkPointUTM-12070' => '1.3.6.1.4.1.2620.1.6.123.1.8',
  'checkPointUTM-13070' => '1.3.6.1.4.1.2620.1.6.123.1.9',
  'checkPointPower-15070' => '1.3.6.1.4.1.2620.1.6.123.1.10',
  'checkPointPower-19070' => '1.3.6.1.4.1.2620.1.6.123.1.11',
  'checkPointPower-111000' => '1.3.6.1.4.1.2620.1.6.123.1.12',
  'checkPointSmart-15' => '1.3.6.1.4.1.2620.1.6.123.1.13',
  'checkPointSmart-125' => '1.3.6.1.4.1.2620.1.6.123.1.14',
  'checkPointSmart-150' => '1.3.6.1.4.1.2620.1.6.123.1.15',
  'checkPointSmart-1150' => '1.3.6.1.4.1.2620.1.6.123.1.16',
  'checkPointIP150' => '1.3.6.1.4.1.2620.1.6.123.1.17',
  'checkPointIP280' => '1.3.6.1.4.1.2620.1.6.123.1.18',
  'checkPointIP290' => '1.3.6.1.4.1.2620.1.6.123.1.19',
  'checkPointIP390' => '1.3.6.1.4.1.2620.1.6.123.1.20',
  'checkPointIP560' => '1.3.6.1.4.1.2620.1.6.123.1.21',
  'checkPointIP690' => '1.3.6.1.4.1.2620.1.6.123.1.22',
  'checkPointIP1280' => '1.3.6.1.4.1.2620.1.6.123.1.23',
  'checkPointIP2450' => '1.3.6.1.4.1.2620.1.6.123.1.24',
  'checkPointUNIVERGEUnifiedWall1000' => '1.3.6.1.4.1.2620.1.6.123.1.25',
  'checkPointUNIVERGEUnifiedWall2000' => '1.3.6.1.4.1.2620.1.6.123.1.26',
  'checkPointUNIVERGEUnifiedWall4000' => '1.3.6.1.4.1.2620.1.6.123.1.27',
  'checkPointUNIVERGEUnifiedWall100' => '1.3.6.1.4.1.2620.1.6.123.1.28',
  'checkPointDLP-19571' => '1.3.6.1.4.1.2620.1.6.123.1.29',
  'checkPointDLP-12571' => '1.3.6.1.4.1.2620.1.6.123.1.30',
  'checkPointIPS-12076' => '1.3.6.1.4.1.2620.1.6.123.1.31',
  'checkPointIPS-15076' => '1.3.6.1.4.1.2620.1.6.123.1.32',
  'checkPointIPS-19076' => '1.3.6.1.4.1.2620.1.6.123.1.33',
  'checkPoint2200' => '1.3.6.1.4.1.2620.1.6.123.1.34',
  'checkPoint4200' => '1.3.6.1.4.1.2620.1.6.123.1.35',
  'checkPoint4400' => '1.3.6.1.4.1.2620.1.6.123.1.36',
  'checkPoint4600' => '1.3.6.1.4.1.2620.1.6.123.1.37',
  'checkPoint4800' => '1.3.6.1.4.1.2620.1.6.123.1.38',
  'checkPointTE250' => '1.3.6.1.4.1.2620.1.6.123.1.39',
  'checkPoint12200' => '1.3.6.1.4.1.2620.1.6.123.1.40',
  'checkPoint12400' => '1.3.6.1.4.1.2620.1.6.123.1.41',
  'checkPoint12600' => '1.3.6.1.4.1.2620.1.6.123.1.42',
  'checkPointTE1000' => '1.3.6.1.4.1.2620.1.6.123.1.43',
  'checkPoint13500' => '1.3.6.1.4.1.2620.1.6.123.1.44',
  'checkPoint21400' => '1.3.6.1.4.1.2620.1.6.123.1.45',
  'checkPoint21600' => '1.3.6.1.4.1.2620.1.6.123.1.46',
  'checkPoint21700' => '1.3.6.1.4.1.2620.1.6.123.1.47',
  'checkPointVMware' => '1.3.6.1.4.1.2620.1.6.123.1.48',
  'checkPointOpenServer' => '1.3.6.1.4.1.2620.1.6.123.1.49',
  'checkPointSmart-1205' => '1.3.6.1.4.1.2620.1.6.123.1.50',
  'checkPointSmart-1210' => '1.3.6.1.4.1.2620.1.6.123.1.51',
  'checkPointSmart-1225' => '1.3.6.1.4.1.2620.1.6.123.1.52',
  'checkPointSmart-13050' => '1.3.6.1.4.1.2620.1.6.123.1.53',
  'checkPointSmart-13150' => '1.3.6.1.4.1.2620.1.6.123.1.54',
  'checkPoint13800' => '1.3.6.1.4.1.2620.1.6.123.1.55',
  'checkPoint21800' => '1.3.6.1.4.1.2620.1.6.123.1.56',
  'svnServicePack' => '1.3.6.1.4.1.2620.1.6.999',
  'mngmt' => '1.3.6.1.4.1.2620.1.7',
  'mgProdName' => '1.3.6.1.4.1.2620.1.7.1',
  'mgVerMajor' => '1.3.6.1.4.1.2620.1.7.2',
  'mgVerMinor' => '1.3.6.1.4.1.2620.1.7.3',
  'mgBuildNumber' => '1.3.6.1.4.1.2620.1.7.4',
  'mgActiveStatus' => '1.3.6.1.4.1.2620.1.7.5',
  'mgFwmIsAlive' => '1.3.6.1.4.1.2620.1.7.6',
  'mgConnectedClientsTable' => '1.3.6.1.4.1.2620.1.7.7',
  'mgConnectedClientsEntry' => '1.3.6.1.4.1.2620.1.7.7.1',
  'mgIndex' => '1.3.6.1.4.1.2620.1.7.7.1.1',
  'mgClientName' => '1.3.6.1.4.1.2620.1.7.7.1.2',
  'mgClientHost' => '1.3.6.1.4.1.2620.1.7.7.1.3',
  'mgClientDbLock' => '1.3.6.1.4.1.2620.1.7.7.1.4',
  'mgApplicationType' => '1.3.6.1.4.1.2620.1.7.7.1.5',
  'mgLogServerInfo' => '1.3.6.1.4.1.2620.1.7.14',
  'mgLSLogReceiveRate' => '1.3.6.1.4.1.2620.1.7.14.1',
  'mgLSLogReceiveRatePeak' => '1.3.6.1.4.1.2620.1.7.14.2',
  'mgLSLogReceiveRate10Min' => '1.3.6.1.4.1.2620.1.7.14.3',
  'mgConnectedGatewaysTable' => '1.3.6.1.4.1.2620.1.7.14.4',
  'mgConnectedGatewaysEntry' => '1.3.6.1.4.1.2620.1.7.14.4.1',
  'mglsGWIndex' => '1.3.6.1.4.1.2620.1.7.14.4.1.1',
  'mglsGWIP' => '1.3.6.1.4.1.2620.1.7.14.4.1.2',
  'mglsGWState' => '1.3.6.1.4.1.2620.1.7.14.4.1.3',
  'mglsGWLastLoginTime' => '1.3.6.1.4.1.2620.1.7.14.4.1.4',
  'mglsGWLogReceiveRate' => '1.3.6.1.4.1.2620.1.7.14.4.1.5',
  'mgIndexerInfo' => '1.3.6.1.4.1.2620.1.7.14.5',
  'mgIndexerInfoTotalReadLogs' => '1.3.6.1.4.1.2620.1.7.14.5.1',
  'mgIndexerInfoTotalUpdatesAndLogsIndexed' => '1.3.6.1.4.1.2620.1.7.14.5.2',
  'mgIndexerInfoTotalReadLogsErrors' => '1.3.6.1.4.1.2620.1.7.14.5.3',
  'mgIndexerInfoTotalUpdatesAndLogsIndexedErrors' => '1.3.6.1.4.1.2620.1.7.14.5.4',
  'mgIndexerInfoUpdatesAndLogsIndexedRate' => '1.3.6.1.4.1.2620.1.7.14.5.5',
  'mgIndexerInfoReadLogsRate' => '1.3.6.1.4.1.2620.1.7.14.5.6',
  'mgIndexerInfoUpdatesAndLogsIndexedRate10min' => '1.3.6.1.4.1.2620.1.7.14.5.7',
  'mgIndexerInfoReadLogsRate10min' => '1.3.6.1.4.1.2620.1.7.14.5.8',
  'mgIndexerInfoUpdatesAndLogsIndexedRate60min' => '1.3.6.1.4.1.2620.1.7.14.5.9',
  'mgIndexerInfoReadLogsRate60min' => '1.3.6.1.4.1.2620.1.7.14.5.10',
  'mgIndexerInfoUpdatesAndLogsIndexedRatePeak' => '1.3.6.1.4.1.2620.1.7.14.5.11',
  'mgIndexerInfoReadLogsRatePeak' => '1.3.6.1.4.1.2620.1.7.14.5.12',
  'mgIndexerInfoReadLogsDelay' => '1.3.6.1.4.1.2620.1.7.14.5.13',
  'mgLSLogReceiveRate1Hour' => '1.3.6.1.4.1.2620.1.7.14.6',
  'mgStatCode' => '1.3.6.1.4.1.2620.1.7.101',
  'mgStatShortDescr' => '1.3.6.1.4.1.2620.1.7.102',
  'mgStatLongDescr' => '1.3.6.1.4.1.2620.1.7.103',
  'wam' => '1.3.6.1.4.1.2620.1.8',
  'wamProdName' => '1.3.6.1.4.1.2620.1.8.1',
  'wamVerMajor' => '1.3.6.1.4.1.2620.1.8.2',
  'wamVerMinor' => '1.3.6.1.4.1.2620.1.8.3',
  'wamState' => '1.3.6.1.4.1.2620.1.8.4',
  'wamName' => '1.3.6.1.4.1.2620.1.8.5',
  'wamPluginPerformance' => '1.3.6.1.4.1.2620.1.8.6',
  'wamAcceptReq' => '1.3.6.1.4.1.2620.1.8.6.1',
  'wamRejectReq' => '1.3.6.1.4.1.2620.1.8.6.2',
  'wamPolicy' => '1.3.6.1.4.1.2620.1.8.7',
  'wamPolicyName' => '1.3.6.1.4.1.2620.1.8.7.1',
  'wamPolicyUpdate' => '1.3.6.1.4.1.2620.1.8.7.2',
  'wamUagQueries' => '1.3.6.1.4.1.2620.1.8.8',
  'wamUagHost' => '1.3.6.1.4.1.2620.1.8.8.1',
  'wamUagIp' => '1.3.6.1.4.1.2620.1.8.8.2',
  'wamUagPort' => '1.3.6.1.4.1.2620.1.8.8.3',
  'wamUagNoQueries' => '1.3.6.1.4.1.2620.1.8.8.4',
  'wamUagLastQuery' => '1.3.6.1.4.1.2620.1.8.8.5',
  'wamGlobalPerformance' => '1.3.6.1.4.1.2620.1.8.9',
  'wamOpenSessions' => '1.3.6.1.4.1.2620.1.8.9.1',
  'wamLastSession' => '1.3.6.1.4.1.2620.1.8.9.2',
  'wamStatCode' => '1.3.6.1.4.1.2620.1.8.101',
  'wamStatShortDescr' => '1.3.6.1.4.1.2620.1.8.102',
  'wamStatLongDescr' => '1.3.6.1.4.1.2620.1.8.103',
  'dtps' => '1.3.6.1.4.1.2620.1.9',
  'dtpsProdName' => '1.3.6.1.4.1.2620.1.9.1',
  'dtpsVerMajor' => '1.3.6.1.4.1.2620.1.9.2',
  'dtpsVerMinor' => '1.3.6.1.4.1.2620.1.9.3',
  'dtpsLicensedUsers' => '1.3.6.1.4.1.2620.1.9.4',
  'dtpsConnectedUsers' => '1.3.6.1.4.1.2620.1.9.5',
  'dtpsStatCode' => '1.3.6.1.4.1.2620.1.9.101',
  'dtpsStatShortDescr' => '1.3.6.1.4.1.2620.1.9.102',
  'dtpsStatLongDescr' => '1.3.6.1.4.1.2620.1.9.103',
  'ls' => '1.3.6.1.4.1.2620.1.11',
  'lsProdName' => '1.3.6.1.4.1.2620.1.11.1',
  'lsVerMajor' => '1.3.6.1.4.1.2620.1.11.2',
  'lsVerMinor' => '1.3.6.1.4.1.2620.1.11.3',
  'lsBuildNumber' => '1.3.6.1.4.1.2620.1.11.4',
  'lsFwmIsAlive' => '1.3.6.1.4.1.2620.1.11.5',
  'lsConnectedClientsTable' => '1.3.6.1.4.1.2620.1.11.7',
  'lsConnectedClientsEntry' => '1.3.6.1.4.1.2620.1.11.7.1',
  'lsIndex' => '1.3.6.1.4.1.2620.1.11.7.1.1',
  'lsClientName' => '1.3.6.1.4.1.2620.1.11.7.1.2',
  'lsClientHost' => '1.3.6.1.4.1.2620.1.11.7.1.3',
  'lsClientDbLock' => '1.3.6.1.4.1.2620.1.11.7.1.4',
  'lsApplicationType' => '1.3.6.1.4.1.2620.1.11.7.1.5',
  'lsLoggingInfo' => '1.3.6.1.4.1.2620.1.11.14',
  'lsLogReceiveRate' => '1.3.6.1.4.1.2620.1.11.14.1',
  'lsLogReceiveRatePeak' => '1.3.6.1.4.1.2620.1.11.14.2',
  'lsLogReceiveRate10Min' => '1.3.6.1.4.1.2620.1.11.14.3',
  'lsConnectedGatewaysTable' => '1.3.6.1.4.1.2620.1.11.14.4',
  'lsConnectedGatewaysEntry' => '1.3.6.1.4.1.2620.1.11.14.4.1',
  'lsGWIndex' => '1.3.6.1.4.1.2620.1.11.14.4.1.1',
  'lsGWIP' => '1.3.6.1.4.1.2620.1.11.14.4.1.2',
  'lsGWState' => '1.3.6.1.4.1.2620.1.11.14.4.1.3',
  'lsGWLastLoginTime' => '1.3.6.1.4.1.2620.1.11.14.4.1.4',
  'lsGWLogReceiveRate' => '1.3.6.1.4.1.2620.1.11.14.4.1.5',
  'lsIndexerInfo' => '1.3.6.1.4.1.2620.1.11.14.5',
  'lsIndexerInfoTotalReadLogs' => '1.3.6.1.4.1.2620.1.11.14.5.1',
  'lsIndexerInfoTotalUpdatesAndLogsIndexed' => '1.3.6.1.4.1.2620.1.11.14.5.2',
  'lsIndexerInfoTotalReadLogsErrors' => '1.3.6.1.4.1.2620.1.11.14.5.3',
  'lsIndexerInfoTotalUpdatesAndLogsIndexedErrors' => '1.3.6.1.4.1.2620.1.11.14.5.4',
  'lsIndexerInfoUpdatesAndLogsIndexedRate' => '1.3.6.1.4.1.2620.1.11.14.5.5',
  'lsIndexerInfoReadLogsRate' => '1.3.6.1.4.1.2620.1.11.14.5.6',
  'lsIndexerInfoUpdatesAndLogsIndexedRatePeak' => '1.3.6.1.4.1.2620.1.11.14.5.7',
  'lsIndexerInfoReadLogsRatePeak' => '1.3.6.1.4.1.2620.1.11.14.5.8',
  'lsLogReceiveRate1Hour' => '1.3.6.1.4.1.2620.1.11.14.6',
  'lsStatCode' => '1.3.6.1.4.1.2620.1.11.101',
  'lsStatShortDescr' => '1.3.6.1.4.1.2620.1.11.102',
  'lsStatLongDescr' => '1.3.6.1.4.1.2620.1.11.103',
  'vsx' => '1.3.6.1.4.1.2620.1.16',
  'vsxVsSupported' => '1.3.6.1.4.1.2620.1.16.11',
  'vsxVsConfigured' => '1.3.6.1.4.1.2620.1.16.12',
  'vsxVsInstalled' => '1.3.6.1.4.1.2620.1.16.13',
  'vsxStatus' => '1.3.6.1.4.1.2620.1.16.22',
  'vsxStatusTable' => '1.3.6.1.4.1.2620.1.16.22.1',
  'vsxStatusEntry' => '1.3.6.1.4.1.2620.1.16.22.1.1',
  'vsxStatusVSId' => '1.3.6.1.4.1.2620.1.16.22.1.1.1',
  'vsxStatusVRId' => '1.3.6.1.4.1.2620.1.16.22.1.1.2',
  'vsxStatusVsName' => '1.3.6.1.4.1.2620.1.16.22.1.1.3',
  'vsxStatusVsType' => '1.3.6.1.4.1.2620.1.16.22.1.1.4',
  'vsxStatusMainIP' => '1.3.6.1.4.1.2620.1.16.22.1.1.5',
  'vsxStatusPolicyName' => '1.3.6.1.4.1.2620.1.16.22.1.1.6',
  'vsxStatusVsPolicyType' => '1.3.6.1.4.1.2620.1.16.22.1.1.7',
  'vsxStatusSicTrustState' => '1.3.6.1.4.1.2620.1.16.22.1.1.8',
  'vsxStatusHAState' => '1.3.6.1.4.1.2620.1.16.22.1.1.9',
  'vsxStatusVSWeight' => '1.3.6.1.4.1.2620.1.16.22.1.1.10',
  'vsxStatusCPUUsageTable' => '1.3.6.1.4.1.2620.1.16.22.2',
  'vsxStatusCPUUsageEntry' => '1.3.6.1.4.1.2620.1.16.22.2.1',
  'vsxStatusCPUUsage1sec' => '1.3.6.1.4.1.2620.1.16.22.2.1.1',
  'vsxStatusCPUUsage10sec' => '1.3.6.1.4.1.2620.1.16.22.2.1.2',
  'vsxStatusCPUUsage1min' => '1.3.6.1.4.1.2620.1.16.22.2.1.3',
  'vsxStatusCPUUsage1hr' => '1.3.6.1.4.1.2620.1.16.22.2.1.4',
  'vsxStatusCPUUsage24hr' => '1.3.6.1.4.1.2620.1.16.22.2.1.5',
  'vsxStatusCPUUsageVSId' => '1.3.6.1.4.1.2620.1.16.22.2.1.6',
  'vsxCounters' => '1.3.6.1.4.1.2620.1.16.23',
  'vsxCountersTable' => '1.3.6.1.4.1.2620.1.16.23.1',
  'vsxCountersEntry' => '1.3.6.1.4.1.2620.1.16.23.1.1',
  'vsxCountersVSId' => '1.3.6.1.4.1.2620.1.16.23.1.1.1',
  'vsxCountersConnNum' => '1.3.6.1.4.1.2620.1.16.23.1.1.2',
  'vsxCountersConnPeakNum' => '1.3.6.1.4.1.2620.1.16.23.1.1.3',
  'vsxCountersConnTableLimit' => '1.3.6.1.4.1.2620.1.16.23.1.1.4',
  'vsxCountersPackets' => '1.3.6.1.4.1.2620.1.16.23.1.1.5',
  'vsxCountersDroppedTotal' => '1.3.6.1.4.1.2620.1.16.23.1.1.6',
  'vsxCountersAcceptedTotal' => '1.3.6.1.4.1.2620.1.16.23.1.1.7',
  'vsxCountersRejectedTotal' => '1.3.6.1.4.1.2620.1.16.23.1.1.8',
  'vsxCountersBytesAcceptedTotal' => '1.3.6.1.4.1.2620.1.16.23.1.1.9',
  'vsxCountersBytesDroppedTotal' => '1.3.6.1.4.1.2620.1.16.23.1.1.10',
  'vsxCountersBytesRejectedTotal' => '1.3.6.1.4.1.2620.1.16.23.1.1.11',
  'vsxCountersLoggedTotal' => '1.3.6.1.4.1.2620.1.16.23.1.1.12',
  'vsxCountersIsDataValid' => '1.3.6.1.4.1.2620.1.16.23.1.1.13',
  'smartDefense' => '1.3.6.1.4.1.2620.1.17',
  'asmAttacks' => '1.3.6.1.4.1.2620.1.17.1',
  'asmLayer3' => '1.3.6.1.4.1.2620.1.17.1.1',
  'asmLayer4' => '1.3.6.1.4.1.2620.1.17.1.2',
  'asmTCP' => '1.3.6.1.4.1.2620.1.17.1.2.1',
  'asmSynatk' => '1.3.6.1.4.1.2620.1.17.1.2.1.1',
  'asmSynatkSynAckTimeout' => '1.3.6.1.4.1.2620.1.17.1.2.1.1.1',
  'asmSynatkSynAckReset' => '1.3.6.1.4.1.2620.1.17.1.2.1.1.2',
  'asmSynatkModeChange' => '1.3.6.1.4.1.2620.1.17.1.2.1.1.3',
  'asmSynatkCurrentMode' => '1.3.6.1.4.1.2620.1.17.1.2.1.1.4',
  'asmSynatkNumberofunAckedSyns' => '1.3.6.1.4.1.2620.1.17.1.2.1.1.5',
  'asmSmallPmtu' => '1.3.6.1.4.1.2620.1.17.1.2.1.2',
  'smallPMTUNumberOfAttacks' => '1.3.6.1.4.1.2620.1.17.1.2.1.2.1',
  'smallPMTUValueOfMinimalMTUsize' => '1.3.6.1.4.1.2620.1.17.1.2.1.2.2',
  'asmSeqval' => '1.3.6.1.4.1.2620.1.17.1.2.1.3',
  'sequenceVerifierInvalidAck' => '1.3.6.1.4.1.2620.1.17.1.2.1.3.1',
  'sequenceVerifierInvalidSequence' => '1.3.6.1.4.1.2620.1.17.1.2.1.3.2',
  'sequenceVerifierInvalidretransmit' => '1.3.6.1.4.1.2620.1.17.1.2.1.3.3',
  'asmUDP' => '1.3.6.1.4.1.2620.1.17.1.2.2',
  'asmScans' => '1.3.6.1.4.1.2620.1.17.1.2.3',
  'asmHostPortScan' => '1.3.6.1.4.1.2620.1.17.1.2.3.1',
  'numOfhostPortScan' => '1.3.6.1.4.1.2620.1.17.1.2.3.1.1',
  'asmIPSweep' => '1.3.6.1.4.1.2620.1.17.1.2.3.2',
  'numOfIpSweep' => '1.3.6.1.4.1.2620.1.17.1.2.3.2.1',
  'asmLayer5' => '1.3.6.1.4.1.2620.1.17.1.3',
  'asmHTTP' => '1.3.6.1.4.1.2620.1.17.1.3.1',
  'asmHttpWorms' => '1.3.6.1.4.1.2620.1.17.1.3.1.1',
  'httpWorms' => '1.3.6.1.4.1.2620.1.17.1.3.1.1.1',
  'asmHttpFormatViolatoin' => '1.3.6.1.4.1.2620.1.17.1.3.1.2',
  'httpURLLengthViolation' => '1.3.6.1.4.1.2620.1.17.1.3.1.2.1',
  'httpHeaderLengthViolations' => '1.3.6.1.4.1.2620.1.17.1.3.1.2.2',
  'httpMaxHeaderReached' => '1.3.6.1.4.1.2620.1.17.1.3.1.2.3',
  'asmHttpAsciiViolation' => '1.3.6.1.4.1.2620.1.17.1.3.1.3',
  'numOfHttpASCIIViolations' => '1.3.6.1.4.1.2620.1.17.1.3.1.3.1',
  'asmHttpP2PHeaderFilter' => '1.3.6.1.4.1.2620.1.17.1.3.1.4',
  'numOfHttpP2PHeaders' => '1.3.6.1.4.1.2620.1.17.1.3.1.4.1',
  'asmCIFS' => '1.3.6.1.4.1.2620.1.17.1.3.2',
  'asmCIFSWorms' => '1.3.6.1.4.1.2620.1.17.1.3.2.1',
  'numOfCIFSworms' => '1.3.6.1.4.1.2620.1.17.1.3.2.1.1',
  'asmCIFSNullSession' => '1.3.6.1.4.1.2620.1.17.1.3.2.2',
  'numOfCIFSNullSessions' => '1.3.6.1.4.1.2620.1.17.1.3.2.2.1',
  'asmCIFSBlockedPopUps' => '1.3.6.1.4.1.2620.1.17.1.3.2.3',
  'numOfCIFSBlockedPopUps' => '1.3.6.1.4.1.2620.1.17.1.3.2.3.1',
  'asmCIFSBlockedCommands' => '1.3.6.1.4.1.2620.1.17.1.3.2.4',
  'numOfCIFSBlockedCommands' => '1.3.6.1.4.1.2620.1.17.1.3.2.4.1',
  'asmCIFSPasswordLengthViolations' => '1.3.6.1.4.1.2620.1.17.1.3.2.5',
  'numOfCIFSPasswordLengthViolations' => '1.3.6.1.4.1.2620.1.17.1.3.2.5.1',
  'asmP2P' => '1.3.6.1.4.1.2620.1.17.1.3.3',
  'asmP2POtherConAttempts' => '1.3.6.1.4.1.2620.1.17.1.3.3.1',
  'numOfP2POtherConAttempts' => '1.3.6.1.4.1.2620.1.17.1.3.3.1.1',
  'asmP2PKazaaConAttempts' => '1.3.6.1.4.1.2620.1.17.1.3.3.2',
  'numOfP2PKazaaConAttempts' => '1.3.6.1.4.1.2620.1.17.1.3.3.2.1',
  'asmP2PeMuleConAttempts' => '1.3.6.1.4.1.2620.1.17.1.3.3.3',
  'numOfP2PeMuleConAttempts' => '1.3.6.1.4.1.2620.1.17.1.3.3.3.1',
  'asmP2PGnutellaConAttempts' => '1.3.6.1.4.1.2620.1.17.1.3.3.4',
  'numOfGnutellaConAttempts' => '1.3.6.1.4.1.2620.1.17.1.3.3.4.1',
  'asmP2PSkypeCon' => '1.3.6.1.4.1.2620.1.17.1.3.3.5',
  'numOfP2PSkypeCon' => '1.3.6.1.4.1.2620.1.17.1.3.3.5.1',
  'asmP2PBitTorrentCon' => '1.3.6.1.4.1.2620.1.17.1.3.3.6',
  'numOfBitTorrentCon' => '1.3.6.1.4.1.2620.1.17.1.3.3.6.1',
  'avi' => '1.3.6.1.4.1.2620.1.24',
  'aviEngines' => '1.3.6.1.4.1.2620.1.24.1',
  'aviEngineTable' => '1.3.6.1.4.1.2620.1.24.1.1',
  'aviEngineEntry' => '1.3.6.1.4.1.2620.1.24.1.1.1',
  'aviEngineIndex' => '1.3.6.1.4.1.2620.1.24.1.1.1.1',
  'aviEngineName' => '1.3.6.1.4.1.2620.1.24.1.1.1.2',
  'aviEngineVer' => '1.3.6.1.4.1.2620.1.24.1.1.1.3',
  'aviEngineDate' => '1.3.6.1.4.1.2620.1.24.1.1.1.4',
  'aviSignatureName' => '1.3.6.1.4.1.2620.1.24.1.1.1.5',
  'aviSignatureVer' => '1.3.6.1.4.1.2620.1.24.1.1.1.6',
  'aviSignatureDate' => '1.3.6.1.4.1.2620.1.24.1.1.1.7',
  'aviLastSigCheckTime' => '1.3.6.1.4.1.2620.1.24.1.1.1.8',
  'aviLastSigLocation' => '1.3.6.1.4.1.2620.1.24.1.1.1.9',
  'aviLastLicExp' => '1.3.6.1.4.1.2620.1.24.1.1.1.10',
  'aviTopViruses' => '1.3.6.1.4.1.2620.1.24.2',
  'aviTopVirusesTable' => '1.3.6.1.4.1.2620.1.24.2.1',
  'aviTopVirusesEntry' => '1.3.6.1.4.1.2620.1.24.2.1.1',
  'aviTopVirusesIndex' => '1.3.6.1.4.1.2620.1.24.2.1.1.1',
  'aviTopVirusesName' => '1.3.6.1.4.1.2620.1.24.2.1.1.2',
  'aviTopVirusesCnt' => '1.3.6.1.4.1.2620.1.24.2.1.1.3',
  'aviTopEverViruses' => '1.3.6.1.4.1.2620.1.24.3',
  'aviTopEverVirusesTable' => '1.3.6.1.4.1.2620.1.24.3.1',
  'aviTopEverVirusesEntry' => '1.3.6.1.4.1.2620.1.24.3.1.1',
  'aviTopEverVirusesIndex' => '1.3.6.1.4.1.2620.1.24.3.1.1.1',
  'aviTopEverVirusesName' => '1.3.6.1.4.1.2620.1.24.3.1.1.2',
  'aviTopEverVirusesCnt' => '1.3.6.1.4.1.2620.1.24.3.1.1.3',
  'aviServices' => '1.3.6.1.4.1.2620.1.24.4',
  'aviServicesHTTP' => '1.3.6.1.4.1.2620.1.24.4.1',
  'aviHTTPState' => '1.3.6.1.4.1.2620.1.24.4.1.1',
  'aviHTTPLastVirusName' => '1.3.6.1.4.1.2620.1.24.4.1.2',
  'aviHTTPLastVirusTime' => '1.3.6.1.4.1.2620.1.24.4.1.3',
  'aviHTTPTopVirusesTable' => '1.3.6.1.4.1.2620.1.24.4.1.4',
  'aviHTTPTopVirusesEntry' => '1.3.6.1.4.1.2620.1.24.4.1.4.1',
  'aviHTTPTopVirusesIndex' => '1.3.6.1.4.1.2620.1.24.4.1.4.1.1',
  'aviHTTPTopVirusesName' => '1.3.6.1.4.1.2620.1.24.4.1.4.1.2',
  'aviHTTPTopVirusesCnt' => '1.3.6.1.4.1.2620.1.24.4.1.4.1.3',
  'aviServicesFTP' => '1.3.6.1.4.1.2620.1.24.4.2',
  'aviFTPState' => '1.3.6.1.4.1.2620.1.24.4.2.1',
  'aviFTPLastVirusName' => '1.3.6.1.4.1.2620.1.24.4.2.2',
  'aviFTPLastVirusTime' => '1.3.6.1.4.1.2620.1.24.4.2.3',
  'aviFTPTopVirusesTable' => '1.3.6.1.4.1.2620.1.24.4.2.4',
  'aviFTPTopVirusesEntry' => '1.3.6.1.4.1.2620.1.24.4.2.4.1',
  'aviFTPTopVirusesIndex' => '1.3.6.1.4.1.2620.1.24.4.2.4.1.1',
  'aviFTPTopVirusesName' => '1.3.6.1.4.1.2620.1.24.4.2.4.1.2',
  'aviFTPTopVirusesCnt' => '1.3.6.1.4.1.2620.1.24.4.2.4.1.3',
  'aviServicesSMTP' => '1.3.6.1.4.1.2620.1.24.4.3',
  'aviSMTPState' => '1.3.6.1.4.1.2620.1.24.4.3.1',
  'aviSMTPLastVirusName' => '1.3.6.1.4.1.2620.1.24.4.3.2',
  'aviSMTPLastVirusTime' => '1.3.6.1.4.1.2620.1.24.4.3.3',
  'aviSMTPTopVirusesTable' => '1.3.6.1.4.1.2620.1.24.4.3.4',
  'aviSMTPTopVirusesEntry' => '1.3.6.1.4.1.2620.1.24.4.3.4.1',
  'aviSMTPTopVirusesIndex' => '1.3.6.1.4.1.2620.1.24.4.3.4.1.1',
  'aviSMTPTopVirusesName' => '1.3.6.1.4.1.2620.1.24.4.3.4.1.2',
  'aviSMTPTopVirusesCnt' => '1.3.6.1.4.1.2620.1.24.4.3.4.1.3',
  'aviServicesPOP3' => '1.3.6.1.4.1.2620.1.24.4.4',
  'aviPOP3State' => '1.3.6.1.4.1.2620.1.24.4.4.1',
  'aviPOP3LastVirusName' => '1.3.6.1.4.1.2620.1.24.4.4.2',
  'aviPOP3LastVirusTime' => '1.3.6.1.4.1.2620.1.24.4.4.3',
  'aviPOP3TopVirusesTable' => '1.3.6.1.4.1.2620.1.24.4.4.4',
  'aviPOP3TopVirusesEntry' => '1.3.6.1.4.1.2620.1.24.4.4.4.1',
  'aviPOP3TopVirusesIndex' => '1.3.6.1.4.1.2620.1.24.4.4.4.1.1',
  'aviPOP3TopVirusesName' => '1.3.6.1.4.1.2620.1.24.4.4.4.1.2',
  'aviPOP3TopVirusesCnt' => '1.3.6.1.4.1.2620.1.24.4.4.4.1.3',
  'aviStatCode' => '1.3.6.1.4.1.2620.1.24.101',
  'aviStatShortDescr' => '1.3.6.1.4.1.2620.1.24.102',
  'aviStatLongDescr' => '1.3.6.1.4.1.2620.1.24.103',
  'eventiaAnalyzer' => '1.3.6.1.4.1.2620.1.25',
  'cpsemd' => '1.3.6.1.4.1.2620.1.25.1',
  'cpsemdProcAlive' => '1.3.6.1.4.1.2620.1.25.1.1',
  'cpsemdNewEventsHandled' => '1.3.6.1.4.1.2620.1.25.1.2',
  'cpsemdUpdatesHandled' => '1.3.6.1.4.1.2620.1.25.1.3',
  'cpsemdLastEventTime' => '1.3.6.1.4.1.2620.1.25.1.4',
  'cpsemdCurrentDBSize' => '1.3.6.1.4.1.2620.1.25.1.5',
  'cpsemdDBCapacity' => '1.3.6.1.4.1.2620.1.25.1.6',
  'cpsemdNumEvents' => '1.3.6.1.4.1.2620.1.25.1.7',
  'cpsemdDBDiskSpace' => '1.3.6.1.4.1.2620.1.25.1.8',
  'cpsemdCorrelationUnitTable' => '1.3.6.1.4.1.2620.1.25.1.9',
  'cpsemdCorrelationUnitEntry' => '1.3.6.1.4.1.2620.1.25.1.9.1',
  'cpsemdCorrelationUnitIndex' => '1.3.6.1.4.1.2620.1.25.1.9.1.1',
  'cpsemdCorrelationUnitIP' => '1.3.6.1.4.1.2620.1.25.1.9.1.2',
  'cpsemdCorrelationUnitLastRcvdTime' => '1.3.6.1.4.1.2620.1.25.1.9.1.3',
  'cpsemdCorrelationUnitNumEventsRcvd' => '1.3.6.1.4.1.2620.1.25.1.9.1.4',
  'cpsemdConnectionDuration' => '1.3.6.1.4.1.2620.1.25.1.9.1.5',
  'cpsemdDBIsFull' => '1.3.6.1.4.1.2620.1.25.1.10',
  'cpsemdStatCode' => '1.3.6.1.4.1.2620.1.25.1.101',
  'cpsemdStatShortDescr' => '1.3.6.1.4.1.2620.1.25.1.102',
  'cpsemdStatLongDescr' => '1.3.6.1.4.1.2620.1.25.1.103',
  'cpsead' => '1.3.6.1.4.1.2620.1.25.2',
  'cpseadProcAlive' => '1.3.6.1.4.1.2620.1.25.2.1',
  'cpseadConnectedToSem' => '1.3.6.1.4.1.2620.1.25.2.2',
  'cpseadNumProcessedLogs' => '1.3.6.1.4.1.2620.1.25.2.3',
  'cpseadJobsTable' => '1.3.6.1.4.1.2620.1.25.2.4',
  'cpseadJobsEntry' => '1.3.6.1.4.1.2620.1.25.2.4.1',
  'cpseadJobIndex' => '1.3.6.1.4.1.2620.1.25.2.4.1.1',
  'cpseadJobID' => '1.3.6.1.4.1.2620.1.25.2.4.1.2',
  'cpseadJobName' => '1.3.6.1.4.1.2620.1.25.2.4.1.3',
  'cpseadJobState' => '1.3.6.1.4.1.2620.1.25.2.4.1.4',
  'cpseadJobIsOnline' => '1.3.6.1.4.1.2620.1.25.2.4.1.5',
  'cpseadJobLogServer' => '1.3.6.1.4.1.2620.1.25.2.4.1.6',
  'cpseadJobDataType' => '1.3.6.1.4.1.2620.1.25.2.4.1.7',
  'cpseadConnectedToLogServer' => '1.3.6.1.4.1.2620.1.25.2.4.1.8',
  'cpseadNumAnalyzedLogs' => '1.3.6.1.4.1.2620.1.25.2.4.1.9',
  'cpseadFileName' => '1.3.6.1.4.1.2620.1.25.2.4.1.10',
  'cpseadFileCurrentPosition' => '1.3.6.1.4.1.2620.1.25.2.4.1.11',
  'cpseadStateDescriptionCode' => '1.3.6.1.4.1.2620.1.25.2.4.1.12',
  'cpseadStateDescription' => '1.3.6.1.4.1.2620.1.25.2.4.1.13',
  'cpseadNoFreeDiskSpace' => '1.3.6.1.4.1.2620.1.25.2.5',
  'cpseadStatCode' => '1.3.6.1.4.1.2620.1.25.2.101',
  'cpseadStatShortDescr' => '1.3.6.1.4.1.2620.1.25.2.102',
  'cpseadStatLongDescr' => '1.3.6.1.4.1.2620.1.25.2.103',
  'uf' => '1.3.6.1.4.1.2620.1.29',
  'ufEngine' => '1.3.6.1.4.1.2620.1.29.1',
  'ufEngineName' => '1.3.6.1.4.1.2620.1.29.1.1',
  'ufEngineVer' => '1.3.6.1.4.1.2620.1.29.1.2',
  'ufEngineDate' => '1.3.6.1.4.1.2620.1.29.1.3',
  'ufSignatureDate' => '1.3.6.1.4.1.2620.1.29.1.4',
  'ufSignatureVer' => '1.3.6.1.4.1.2620.1.29.1.5',
  'ufLastSigCheckTime' => '1.3.6.1.4.1.2620.1.29.1.6',
  'ufLastSigLocation' => '1.3.6.1.4.1.2620.1.29.1.7',
  'ufLastLicExp' => '1.3.6.1.4.1.2620.1.29.1.8',
  'ufSS' => '1.3.6.1.4.1.2620.1.29.2',
  'ufIsMonitor' => '1.3.6.1.4.1.2620.1.29.2.1',
  'ufScannedCnt' => '1.3.6.1.4.1.2620.1.29.2.2',
  'ufBlockedCnt' => '1.3.6.1.4.1.2620.1.29.2.3',
  'ufTopBlockedCatTable' => '1.3.6.1.4.1.2620.1.29.2.4',
  'ufTopBlockedCatEntry' => '1.3.6.1.4.1.2620.1.29.2.4.1',
  'ufTopBlockedCatIndex' => '1.3.6.1.4.1.2620.1.29.2.4.1.1',
  'ufTopBlockedCatName' => '1.3.6.1.4.1.2620.1.29.2.4.1.2',
  'ufTopBlockedCatCnt' => '1.3.6.1.4.1.2620.1.29.2.4.1.3',
  'ufTopBlockedSiteTable' => '1.3.6.1.4.1.2620.1.29.2.5',
  'ufTopBlockedSiteEntry' => '1.3.6.1.4.1.2620.1.29.2.5.1',
  'ufTopBlockedSiteIndex' => '1.3.6.1.4.1.2620.1.29.2.5.1.1',
  'ufTopBlockedSiteName' => '1.3.6.1.4.1.2620.1.29.2.5.1.2',
  'ufTopBlockedSiteCnt' => '1.3.6.1.4.1.2620.1.29.2.5.1.3',
  'ufTopBlockedUserTable' => '1.3.6.1.4.1.2620.1.29.2.6',
  'ufTopBlockedUserEntry' => '1.3.6.1.4.1.2620.1.29.2.6.1',
  'ufTopBlockedUserIndex' => '1.3.6.1.4.1.2620.1.29.2.6.1.1',
  'ufTopBlockedUserName' => '1.3.6.1.4.1.2620.1.29.2.6.1.2',
  'ufTopBlockedUserCnt' => '1.3.6.1.4.1.2620.1.29.2.6.1.3',
  'ufStatCode' => '1.3.6.1.4.1.2620.1.29.101',
  'ufStatShortDescr' => '1.3.6.1.4.1.2620.1.29.102',
  'ufStatLongDescr' => '1.3.6.1.4.1.2620.1.29.103',
  'ms' => '1.3.6.1.4.1.2620.1.30',
  'msProductName' => '1.3.6.1.4.1.2620.1.30.1',
  'msMajorVersion' => '1.3.6.1.4.1.2620.1.30.2',
  'msMinorVersion' => '1.3.6.1.4.1.2620.1.30.3',
  'msBuildNumber' => '1.3.6.1.4.1.2620.1.30.4',
  'msVersionStr' => '1.3.6.1.4.1.2620.1.30.5',
  'msSpam' => '1.3.6.1.4.1.2620.1.30.6',
  'msSpamNumScannedEmails' => '1.3.6.1.4.1.2620.1.30.6.1',
  'msSpamNumSpamEmails' => '1.3.6.1.4.1.2620.1.30.6.2',
  'msSpamNumHandledSpamEmails' => '1.3.6.1.4.1.2620.1.30.6.3',
  'msSpamControls' => '1.3.6.1.4.1.2620.1.30.6.4',
  'msSpamControlsSpamEngine' => '1.3.6.1.4.1.2620.1.30.6.4.1',
  'msSpamControlsIpRepuatation' => '1.3.6.1.4.1.2620.1.30.6.4.2',
  'msSpamControlsSPF' => '1.3.6.1.4.1.2620.1.30.6.4.3',
  'msSpamControlsDomainKeys' => '1.3.6.1.4.1.2620.1.30.6.4.4',
  'msSpamControlsRDNS' => '1.3.6.1.4.1.2620.1.30.6.4.5',
  'msSpamControlsRBL' => '1.3.6.1.4.1.2620.1.30.6.4.6',
  'msExpirationDate' => '1.3.6.1.4.1.2620.1.30.7',
  'msEngineVer' => '1.3.6.1.4.1.2620.1.30.8',
  'msEngineDate' => '1.3.6.1.4.1.2620.1.30.9',
  'msStatCode' => '1.3.6.1.4.1.2620.1.30.101',
  'msStatShortDescr' => '1.3.6.1.4.1.2620.1.30.102',
  'msStatLongDescr' => '1.3.6.1.4.1.2620.1.30.103',
  'msServicePack' => '1.3.6.1.4.1.2620.1.30.999',
  'voip' => '1.3.6.1.4.1.2620.1.31',
  'voipProductName' => '1.3.6.1.4.1.2620.1.31.1',
  'voipMajorVersion' => '1.3.6.1.4.1.2620.1.31.2',
  'voipMinorVersion' => '1.3.6.1.4.1.2620.1.31.3',
  'voipBuildNumber' => '1.3.6.1.4.1.2620.1.31.4',
  'voipVersionStr' => '1.3.6.1.4.1.2620.1.31.5',
  'voipDOS' => '1.3.6.1.4.1.2620.1.31.6',
  'voipDOSSip' => '1.3.6.1.4.1.2620.1.31.6.1',
  'voipDOSSipNetwork' => '1.3.6.1.4.1.2620.1.31.6.1.1',
  'voipDOSSipNetworkReqInterval' => '1.3.6.1.4.1.2620.1.31.6.1.1.1',
  'voipDOSSipNetworkReqConfThreshold' => '1.3.6.1.4.1.2620.1.31.6.1.1.2',
  'voipDOSSipNetworkReqCurrentVal' => '1.3.6.1.4.1.2620.1.31.6.1.1.3',
  'voipDOSSipNetworkRegInterval' => '1.3.6.1.4.1.2620.1.31.6.1.1.4',
  'voipDOSSipNetworkRegConfThreshold' => '1.3.6.1.4.1.2620.1.31.6.1.1.5',
  'voipDOSSipNetworkRegCurrentVal' => '1.3.6.1.4.1.2620.1.31.6.1.1.6',
  'voipDOSSipNetworkCallInitInterval' => '1.3.6.1.4.1.2620.1.31.6.1.1.7',
  'voipDOSSipNetworkCallInitConfThreshold' => '1.3.6.1.4.1.2620.1.31.6.1.1.8',
  'voipDOSSipNetworkCallInitICurrentVal' => '1.3.6.1.4.1.2620.1.31.6.1.1.9',
  'voipDOSSipRateLimitingTable' => '1.3.6.1.4.1.2620.1.31.6.1.2',
  'voipDOSSipRateLimitingEntry' => '1.3.6.1.4.1.2620.1.31.6.1.2.1',
  'voipDOSSipRateLimitingTableIndex' => '1.3.6.1.4.1.2620.1.31.6.1.2.1.1',
  'voipDOSSipRateLimitingTableIpAddress' => '1.3.6.1.4.1.2620.1.31.6.1.2.1.2',
  'voipDOSSipRateLimitingTableInterval' => '1.3.6.1.4.1.2620.1.31.6.1.2.1.3',
  'voipDOSSipRateLimitingTableConfThreshold' => '1.3.6.1.4.1.2620.1.31.6.1.2.1.4',
  'voipDOSSipRateLimitingTableNumDOSSipRequests' => '1.3.6.1.4.1.2620.1.31.6.1.2.1.5',
  'voipDOSSipRateLimitingTableNumTrustedRequests' => '1.3.6.1.4.1.2620.1.31.6.1.2.1.6',
  'voipDOSSipRateLimitingTableNumNonTrustedRequests' => '1.3.6.1.4.1.2620.1.31.6.1.2.1.7',
  'voipDOSSipRateLimitingTableNumRequestsfromServers' => '1.3.6.1.4.1.2620.1.31.6.1.2.1.8',
  'voipCAC' => '1.3.6.1.4.1.2620.1.31.7',
  'voipCACConcurrentCalls' => '1.3.6.1.4.1.2620.1.31.7.1',
  'voipCACConcurrentCallsConfThreshold' => '1.3.6.1.4.1.2620.1.31.7.1.1',
  'voipCACConcurrentCallsCurrentVal' => '1.3.6.1.4.1.2620.1.31.7.1.2',
  'voipStatCode' => '1.3.6.1.4.1.2620.1.31.101',
  'voipStatShortDescr' => '1.3.6.1.4.1.2620.1.31.102',
  'voipStatLongDescr' => '1.3.6.1.4.1.2620.1.31.103',
  'voipServicePack' => '1.3.6.1.4.1.2620.1.31.999',
  'sxl' => '1.3.6.1.4.1.2620.1.36',
  'fwSXLGroup' => '1.3.6.1.4.1.2620.1.36.1',
  'fwSXLStatus' => '1.3.6.1.4.1.2620.1.36.1.1',
  'fwSXLStatusDefinition' => 'CHECKPOINT-MIB::fwSXLStatus',
  'fwSXLConnsExisting' => '1.3.6.1.4.1.2620.1.36.1.2',
  'fwSXLConnsAdded' => '1.3.6.1.4.1.2620.1.36.1.3',
  'fwSXLConnsDeleted' => '1.3.6.1.4.1.2620.1.36.1.4',
  'identityAwareness' => '1.3.6.1.4.1.2620.1.38',
  'identityAwarenessProductName' => '1.3.6.1.4.1.2620.1.38.1',
  'identityAwarenessAuthUsers' => '1.3.6.1.4.1.2620.1.38.2',
  'identityAwarenessUnAuthUsers' => '1.3.6.1.4.1.2620.1.38.3',
  'identityAwarenessAuthUsersKerberos' => '1.3.6.1.4.1.2620.1.38.4',
  'identityAwarenessAuthMachKerberos' => '1.3.6.1.4.1.2620.1.38.5',
  'identityAwarenessAuthUsersPass' => '1.3.6.1.4.1.2620.1.38.6',
  'identityAwarenessAuthUsersADQuery' => '1.3.6.1.4.1.2620.1.38.7',
  'identityAwarenessAuthMachADQuery' => '1.3.6.1.4.1.2620.1.38.8',
  'identityAwarenessLoggedInAgent' => '1.3.6.1.4.1.2620.1.38.9',
  'identityAwarenessLoggedInCaptivePortal' => '1.3.6.1.4.1.2620.1.38.10',
  'identityAwarenessLoggedInADQuery' => '1.3.6.1.4.1.2620.1.38.11',
  'identityAwarenessAntiSpoffProtection' => '1.3.6.1.4.1.2620.1.38.12',
  'identityAwarenessSuccUserLoginKerberos' => '1.3.6.1.4.1.2620.1.38.13',
  'identityAwarenessSuccMachLoginKerberos' => '1.3.6.1.4.1.2620.1.38.14',
  'identityAwarenessSuccUserLoginPass' => '1.3.6.1.4.1.2620.1.38.15',
  'identityAwarenessSuccUserLoginADQuery' => '1.3.6.1.4.1.2620.1.38.16',
  'identityAwarenessSuccMachLoginADQuery' => '1.3.6.1.4.1.2620.1.38.17',
  'identityAwarenessUnSuccUserLoginKerberos' => '1.3.6.1.4.1.2620.1.38.18',
  'identityAwarenessUnSuccMachLoginKerberos' => '1.3.6.1.4.1.2620.1.38.19',
  'identityAwarenessUnSuccUserLoginPass' => '1.3.6.1.4.1.2620.1.38.20',
  'identityAwarenessSuccUserLDAP' => '1.3.6.1.4.1.2620.1.38.21',
  'identityAwarenessUnSuccUserLDAP' => '1.3.6.1.4.1.2620.1.38.22',
  'identityAwarenessDataTrans' => '1.3.6.1.4.1.2620.1.38.23',
  'identityAwarenessDistributedEnvTable' => '1.3.6.1.4.1.2620.1.38.24',
  'identityAwarenessDistributedEnvEntry' => '1.3.6.1.4.1.2620.1.38.24.1',
  'identityAwarenessDistributedEnvTableIndex' => '1.3.6.1.4.1.2620.1.38.24.1.1',
  'identityAwarenessDistributedEnvTableGwName' => '1.3.6.1.4.1.2620.1.38.24.1.2',
  'identityAwarenessDistributedEnvTableDisconnections' => '1.3.6.1.4.1.2620.1.38.24.1.3',
  'identityAwarenessDistributedEnvTableBruteForceAtt' => '1.3.6.1.4.1.2620.1.38.24.1.4',
  'identityAwarenessDistributedEnvTableStatus' => '1.3.6.1.4.1.2620.1.38.24.1.5',
  'identityAwarenessDistributedEnvTableIsLocal' => '1.3.6.1.4.1.2620.1.38.24.1.6',
  'identityAwarenessADQueryStatusTable' => '1.3.6.1.4.1.2620.1.38.25',
  'identityAwarenessADQueryStatusEntry' => '1.3.6.1.4.1.2620.1.38.25.1',
  'identityAwarenessADQueryStatusTableIndex' => '1.3.6.1.4.1.2620.1.38.25.1.1',
  'identityAwarenessADQueryStatusCurrStatus' => '1.3.6.1.4.1.2620.1.38.25.1.2',
  'identityAwarenessADQueryStatusDomainName' => '1.3.6.1.4.1.2620.1.38.25.1.3',
  'identityAwarenessADQueryStatusDomainIP' => '1.3.6.1.4.1.2620.1.38.25.1.4',
  'identityAwarenessADQueryStatusEvents' => '1.3.6.1.4.1.2620.1.38.25.1.5',
  'identityAwarenessStatus' => '1.3.6.1.4.1.2620.1.38.101',
  'identityAwarenessStatusShortDesc' => '1.3.6.1.4.1.2620.1.38.102',
  'identityAwarenessStatusLongDesc' => '1.3.6.1.4.1.2620.1.38.103',
  'applicationControl' => '1.3.6.1.4.1.2620.1.39',
  'applicationControlSubscription' => '1.3.6.1.4.1.2620.1.39.1',
  'applicationControlSubscriptionStatus' => '1.3.6.1.4.1.2620.1.39.1.1',
  'applicationControlSubscriptionExpDate' => '1.3.6.1.4.1.2620.1.39.1.2',
  'applicationControlSubscriptionDesc' => '1.3.6.1.4.1.2620.1.39.1.3',
  'applicationControlUpdate' => '1.3.6.1.4.1.2620.1.39.2',
  'applicationControlUpdateStatus' => '1.3.6.1.4.1.2620.1.39.2.1',
  'applicationControlUpdateDesc' => '1.3.6.1.4.1.2620.1.39.2.2',
  'applicationControlNextUpdate' => '1.3.6.1.4.1.2620.1.39.2.3',
  'applicationControlVersion' => '1.3.6.1.4.1.2620.1.39.2.4',
  'applicationControlStatusCode' => '1.3.6.1.4.1.2620.1.39.101',
  'applicationControlStatusShortDesc' => '1.3.6.1.4.1.2620.1.39.102',
  'applicationControlStatusLongDesc' => '1.3.6.1.4.1.2620.1.39.103',
  'thresholds' => '1.3.6.1.4.1.2620.1.42',
  'thresholdPolicy' => '1.3.6.1.4.1.2620.1.42.1',
  'thresholdState' => '1.3.6.1.4.1.2620.1.42.2',
  'thresholdStateDesc' => '1.3.6.1.4.1.2620.1.42.3',
  'thresholdEnabled' => '1.3.6.1.4.1.2620.1.42.4',
  'thresholdActive' => '1.3.6.1.4.1.2620.1.42.5',
  'thresholdEventsSinceStartup' => '1.3.6.1.4.1.2620.1.42.6',
  'thresholdActiveEventsTable' => '1.3.6.1.4.1.2620.1.42.7',
  'thresholdActiveEventsEntry' => '1.3.6.1.4.1.2620.1.42.7.1',
  'thresholdActiveEventsIndex' => '1.3.6.1.4.1.2620.1.42.7.1.1',
  'thresholdActiveEventName' => '1.3.6.1.4.1.2620.1.42.7.1.2',
  'thresholdActiveEventCategory' => '1.3.6.1.4.1.2620.1.42.7.1.3',
  'thresholdActiveEventSeverity' => '1.3.6.1.4.1.2620.1.42.7.1.4',
  'thresholdActiveEventSubject' => '1.3.6.1.4.1.2620.1.42.7.1.5',
  'thresholdActiveEventSubjectValue' => '1.3.6.1.4.1.2620.1.42.7.1.6',
  'thresholdActiveEventActivationTime' => '1.3.6.1.4.1.2620.1.42.7.1.7',
  'thresholdActiveEventState' => '1.3.6.1.4.1.2620.1.42.7.1.8',
  'thresholdDestinationsTable' => '1.3.6.1.4.1.2620.1.42.8',
  'thresholdDestinationsEntry' => '1.3.6.1.4.1.2620.1.42.8.1',
  'thresholdDestinationIndex' => '1.3.6.1.4.1.2620.1.42.8.1.1',
  'thresholdDestinationName' => '1.3.6.1.4.1.2620.1.42.8.1.2',
  'thresholdDestinationType' => '1.3.6.1.4.1.2620.1.42.8.1.3',
  'thresholdSendingState' => '1.3.6.1.4.1.2620.1.42.8.1.4',
  'thresholdSendingStateDesc' => '1.3.6.1.4.1.2620.1.42.8.1.5',
  'thresholdAlertCount' => '1.3.6.1.4.1.2620.1.42.8.1.6',
  'thresholdErrorsTable' => '1.3.6.1.4.1.2620.1.42.9',
  'thresholdErrorsEntry' => '1.3.6.1.4.1.2620.1.42.9.1',
  'thresholdErrorIndex' => '1.3.6.1.4.1.2620.1.42.9.1.1',
  'thresholdName' => '1.3.6.1.4.1.2620.1.42.9.1.2',
  'thresholdThresholdOID' => '1.3.6.1.4.1.2620.1.42.9.1.3',
  'thresholdErrorDesc' => '1.3.6.1.4.1.2620.1.42.9.1.4',
  'thresholdErrorTime' => '1.3.6.1.4.1.2620.1.42.9.1.5',
  'advancedUrlFiltering' => '1.3.6.1.4.1.2620.1.43',
  'advancedUrlFilteringSubscription' => '1.3.6.1.4.1.2620.1.43.1',
  'advancedUrlFilteringSubscriptionStatus' => '1.3.6.1.4.1.2620.1.43.1.1',
  'advancedUrlFilteringSubscriptionExpDate' => '1.3.6.1.4.1.2620.1.43.1.2',
  'advancedUrlFilteringSubscriptionDesc' => '1.3.6.1.4.1.2620.1.43.1.3',
  'advancedUrlFilteringUpdate' => '1.3.6.1.4.1.2620.1.43.2',
  'advancedUrlFilteringUpdateStatus' => '1.3.6.1.4.1.2620.1.43.2.1',
  'advancedUrlFilteringUpdateDesc' => '1.3.6.1.4.1.2620.1.43.2.2',
  'advancedUrlFilteringNextUpdate' => '1.3.6.1.4.1.2620.1.43.2.3',
  'advancedUrlFilteringVersion' => '1.3.6.1.4.1.2620.1.43.2.4',
  'advancedUrlFilteringRADStatus' => '1.3.6.1.4.1.2620.1.43.3',
  'advancedUrlFilteringRADStatusCode' => '1.3.6.1.4.1.2620.1.43.3.1',
  'advancedUrlFilteringRADStatusDesc' => '1.3.6.1.4.1.2620.1.43.3.2',
  'advancedUrlFilteringStatusCode' => '1.3.6.1.4.1.2620.1.43.101',
  'advancedUrlFilteringStatusShortDesc' => '1.3.6.1.4.1.2620.1.43.102',
  'advancedUrlFilteringStatusLongDesc' => '1.3.6.1.4.1.2620.1.43.103',
  'dlp' => '1.3.6.1.4.1.2620.1.44',
  'exchangeAgents' => '1.3.6.1.4.1.2620.1.44.1',
  #'exchangeAgentsTable' => '1.3.6.1.4.1.2620.1.44.1.1',
  'exchangeAgentsStatusTable' => '1.3.6.1.4.1.2620.1.44.1.1',
  'exchangeAgentsStatusEntry' => '1.3.6.1.4.1.2620.1.44.1.1.1',
  'exchangeAgentsStatusTableIndex' => '1.3.6.1.4.1.2620.1.44.1.1.1.1',
  'exchangeAgentName' => '1.3.6.1.4.1.2620.1.44.1.1.1.2',
  'exchangeAgentStatus' => '1.3.6.1.4.1.2620.1.44.1.1.1.3',
  'exchangeAgentTotalMsg' => '1.3.6.1.4.1.2620.1.44.1.1.1.4',
  'exchangeAgentTotalScannedMsg' => '1.3.6.1.4.1.2620.1.44.1.1.1.5',
  'exchangeAgentDroppedMsg' => '1.3.6.1.4.1.2620.1.44.1.1.1.6',
  'exchangeAgentUpTime' => '1.3.6.1.4.1.2620.1.44.1.1.1.7',
  'exchangeAgentTimeSinceLastMsg' => '1.3.6.1.4.1.2620.1.44.1.1.1.8',
  'exchangeAgentQueueLen' => '1.3.6.1.4.1.2620.1.44.1.1.1.9',
  'exchangeQueueLen' => '1.3.6.1.4.1.2620.1.44.1.1.1.10',
  'exchangeAgentAvgTimePerMsg' => '1.3.6.1.4.1.2620.1.44.1.1.1.11',
  'exchangeAgentAvgTimePerScannedMsg' => '1.3.6.1.4.1.2620.1.44.1.1.1.12',
  'exchangeAgentVersion' => '1.3.6.1.4.1.2620.1.44.1.1.1.13',
  'exchangeCPUUsage' => '1.3.6.1.4.1.2620.1.44.1.1.1.14',
  'exchangeMemoryUsage' => '1.3.6.1.4.1.2620.1.44.1.1.1.15',
  'exchangeAgentPolicyTimeStamp' => '1.3.6.1.4.1.2620.1.44.1.1.1.16',
  'dlpVersionString' => '1.3.6.1.4.1.2620.1.44.11',
  'dlpLicenseStatus' => '1.3.6.1.4.1.2620.1.44.12',
  'dlpLdapStatus' => '1.3.6.1.4.1.2620.1.44.13',
  'dlpTotalScans' => '1.3.6.1.4.1.2620.1.44.14',
  'dlpSMTPScans' => '1.3.6.1.4.1.2620.1.44.15',
  'dlpSMTPIncidents' => '1.3.6.1.4.1.2620.1.44.16',
  'dlpLastSMTPScan' => '1.3.6.1.4.1.2620.1.44.17',
  'dlpNumQuarantined' => '1.3.6.1.4.1.2620.1.44.18',
  'dlpQrntMsgsSize' => '1.3.6.1.4.1.2620.1.44.19',
  'dlpSentEMails' => '1.3.6.1.4.1.2620.1.44.20',
  'dlpExpiredEMails' => '1.3.6.1.4.1.2620.1.44.21',
  'dlpDiscardEMails' => '1.3.6.1.4.1.2620.1.44.22',
  'dlpPostfixQLen' => '1.3.6.1.4.1.2620.1.44.23',
  'dlpPostfixErrors' => '1.3.6.1.4.1.2620.1.44.24',
  'dlpPostfixQOldMsg' => '1.3.6.1.4.1.2620.1.44.25',
  'dlpPostfixQMsgsSz' => '1.3.6.1.4.1.2620.1.44.26',
  'dlpPostfixQFreeSp' => '1.3.6.1.4.1.2620.1.44.27',
  'dlpQrntFreeSpace' => '1.3.6.1.4.1.2620.1.44.28',
  'dlpQrntStatus' => '1.3.6.1.4.1.2620.1.44.29',
  'dlpHttpScans' => '1.3.6.1.4.1.2620.1.44.30',
  'dlpHttpIncidents' => '1.3.6.1.4.1.2620.1.44.31',
  'dlpHttpLastScan' => '1.3.6.1.4.1.2620.1.44.32',
  'dlpFtpScans' => '1.3.6.1.4.1.2620.1.44.33',
  'dlpFtpIncidents' => '1.3.6.1.4.1.2620.1.44.34',
  'dlpFtpLastScan' => '1.3.6.1.4.1.2620.1.44.35',
  'dlpBypassStatus' => '1.3.6.1.4.1.2620.1.44.36',
  'dlpUserCheckClnts' => '1.3.6.1.4.1.2620.1.44.37',
  'dlpLastPolStatus' => '1.3.6.1.4.1.2620.1.44.38',
  'dlpStatusCode' => '1.3.6.1.4.1.2620.1.44.101',
  'dlpStatusShortDesc' => '1.3.6.1.4.1.2620.1.44.102',
  'dlpStatusLongDesc' => '1.3.6.1.4.1.2620.1.44.103',
  'amw' => '1.3.6.1.4.1.2620.1.46',
  'amwABUpdate' => '1.3.6.1.4.1.2620.1.46.1',
  'amwABUpdateStatus' => '1.3.6.1.4.1.2620.1.46.1.1',
  'amwABUpdateDesc' => '1.3.6.1.4.1.2620.1.46.1.2',
  'amwABNextUpdate' => '1.3.6.1.4.1.2620.1.46.1.3',
  'amwABVersion' => '1.3.6.1.4.1.2620.1.46.1.4',
  'antiBotSubscription' => '1.3.6.1.4.1.2620.1.46.2',
  'antiBotSubscriptionStatus' => '1.3.6.1.4.1.2620.1.46.2.1',
  'antiBotSubscriptionExpDate' => '1.3.6.1.4.1.2620.1.46.2.2',
  'antiBotSubscriptionDesc' => '1.3.6.1.4.1.2620.1.46.2.3',
  'antiVirusSubscription' => '1.3.6.1.4.1.2620.1.46.3',
  'antiVirusSubscriptionStatus' => '1.3.6.1.4.1.2620.1.46.3.1',
  'antiVirusSubscriptionExpDate' => '1.3.6.1.4.1.2620.1.46.3.2',
  'antiVirusSubscriptionDesc' => '1.3.6.1.4.1.2620.1.46.3.3',
  'antiSpamSubscription' => '1.3.6.1.4.1.2620.1.46.4',
  'antiSpamSubscriptionStatus' => '1.3.6.1.4.1.2620.1.46.4.1',
  'antiSpamSubscriptionExpDate' => '1.3.6.1.4.1.2620.1.46.4.2',
  'antiSpamSubscriptionDesc' => '1.3.6.1.4.1.2620.1.46.4.3',
  'amwAVUpdate' => '1.3.6.1.4.1.2620.1.46.5',
  'amwAVUpdateStatus' => '1.3.6.1.4.1.2620.1.46.5.1',
  'amwAVUpdateDesc' => '1.3.6.1.4.1.2620.1.46.5.2',
  'amwAVNextUpdate' => '1.3.6.1.4.1.2620.1.46.5.3',
  'amwAVVersion' => '1.3.6.1.4.1.2620.1.46.5.4',
  'amwStatusCode' => '1.3.6.1.4.1.2620.1.46.101',
  'amwStatusShortDesc' => '1.3.6.1.4.1.2620.1.46.102',
  'amwStatusLongDesc' => '1.3.6.1.4.1.2620.1.46.103',
  'te' => '1.3.6.1.4.1.2620.1.49',
  'teUpdateStatus' => '1.3.6.1.4.1.2620.1.49.16',
  'teUpdateDesc' => '1.3.6.1.4.1.2620.1.49.17',
  'teSubscriptionExpDate' => '1.3.6.1.4.1.2620.1.49.20',
  'teSubscriptionStatus' => '1.3.6.1.4.1.2620.1.49.25',
  'teCloudSubscriptionStatus' => '1.3.6.1.4.1.2620.1.49.26',
  'teSubscriptionDesc' => '1.3.6.1.4.1.2620.1.49.27',
  'teStatusCode' => '1.3.6.1.4.1.2620.1.49.101',
  'teStatusShortDesc' => '1.3.6.1.4.1.2620.1.49.102',
  'teStatusLongDesc' => '1.3.6.1.4.1.2620.1.49.103',
  'tables' => '1.3.6.1.4.1.2620.500',
  'raUsersTable' => '1.3.6.1.4.1.2620.500.9000',
  'raUsersEntry' => '1.3.6.1.4.1.2620.500.9000.1',
  'raInternalIpAddr' => '1.3.6.1.4.1.2620.500.9000.1.1',
  'raExternalIpAddr' => '1.3.6.1.4.1.2620.500.9000.1.19',
  'raUserState' => '1.3.6.1.4.1.2620.500.9000.1.20',
  'raUserStateDefinition' => 'CHECKPOINT-MIB::raUserState',
  'raOfficeMode' => '1.3.6.1.4.1.2620.500.9000.1.21',
  'raIkeOverTCP' => '1.3.6.1.4.1.2620.500.9000.1.22',
  'raUseUDPEncap' => '1.3.6.1.4.1.2620.500.9000.1.23',
  'raVisitorMode' => '1.3.6.1.4.1.2620.500.9000.1.24',
  'raRouteTraffic' => '1.3.6.1.4.1.2620.500.9000.1.25',
  'raCommunity' => '1.3.6.1.4.1.2620.500.9000.1.26',
  'raTunnelEncAlgorithm' => '1.3.6.1.4.1.2620.500.9000.1.27',
  'raTunnelEncAlgorithmDefinition' => 'CHECKPOINT-MIB::raTunnelEncAlgorithm',
  'raTunnelAuthMethod' => '1.3.6.1.4.1.2620.500.9000.1.28',
  'raTunnelAuthMethodDefinition' => 'CHECKPOINT-MIB::raTunnelAuthMethod',
  'raLogonTime' => '1.3.6.1.4.1.2620.500.9000.1.29',
  'tunnelTable' => '1.3.6.1.4.1.2620.500.9002',
  'tunnelEntry' => '1.3.6.1.4.1.2620.500.9002.1',
  'tunnelPeerIpAddr' => '1.3.6.1.4.1.2620.500.9002.1.1',
  'tunnelPeerObjName' => '1.3.6.1.4.1.2620.500.9002.1.2',
  'tunnelState' => '1.3.6.1.4.1.2620.500.9002.1.3',
  'tunnelStateDefinition' => 'CHECKPOINT-MIB::tunnelState',
  'tunnelCommunity' => '1.3.6.1.4.1.2620.500.9002.1.4',
  'tunnelNextHop' => '1.3.6.1.4.1.2620.500.9002.1.5',
  'tunnelInterface' => '1.3.6.1.4.1.2620.500.9002.1.6',
  'tunnelSourceIpAddr' => '1.3.6.1.4.1.2620.500.9002.1.7',
  'tunnelLinkPriority' => '1.3.6.1.4.1.2620.500.9002.1.8',
  'tunnelLinkPriorityDefinition' => 'CHECKPOINT-MIB::tunnelLinkPriority',
  'tunnelProbState' => '1.3.6.1.4.1.2620.500.9002.1.9',
  'tunnelProbStateDefinition' => 'CHECKPOINT-MIB::tunnelProbState',
  'tunnelPeerType' => '1.3.6.1.4.1.2620.500.9002.1.10',
  'tunnelPeerTypeDefinition' => 'CHECKPOINT-MIB::tunnelPeerType',
  'tunnelType' => '1.3.6.1.4.1.2620.500.9002.1.11',
  'tunnelTypeDefinition' => 'CHECKPOINT-MIB::tunnelType',
  'permanentTunnelTable' => '1.3.6.1.4.1.2620.500.9003',
  'permanentTunnelEntry' => '1.3.6.1.4.1.2620.500.9003.1',
  'permanentTunnelPeerIpAddr' => '1.3.6.1.4.1.2620.500.9003.1.1',
  'permanentTunnelPeerObjName' => '1.3.6.1.4.1.2620.500.9003.1.2',
  'permanentTunnelState' => '1.3.6.1.4.1.2620.500.9003.1.3',
  'permanentTunnelStateDefinition' => 'CHECKPOINT-MIB::permanentTunnelState',
  'permanentTunnelCommunity' => '1.3.6.1.4.1.2620.500.9003.1.4',
  'permanentTunnelNextHop' => '1.3.6.1.4.1.2620.500.9003.1.5',
  'permanentTunnelInterface' => '1.3.6.1.4.1.2620.500.9003.1.6',
  'permanentTunnelSourceIpAddr' => '1.3.6.1.4.1.2620.500.9003.1.7',
  'permanentTunnelLinkPriority' => '1.3.6.1.4.1.2620.500.9003.1.8',
  'permanentTunnelLinkPriorityDefinition' => 'CHECKPOINT-MIB::permanentTunnelLinkPriority',
  'permanentTunnelProbState' => '1.3.6.1.4.1.2620.500.9003.1.9',
  'permanentTunnelProbStateDefinition' => 'CHECKPOINT-MIB::permanentTunnelProbState',
  'permanentTunnelPeerType' => '1.3.6.1.4.1.2620.500.9003.1.10',
  'permanentTunnelPeerTypeDefinition' => 'CHECKPOINT-MIB::permanentTunnelPeerType',
};

$Monitoring::GLPlugin::SNMP::MibsAndOids::definitions->{'CHECKPOINT-MIB'} = {
  raTunnelAuthMethod => {
    '1' => 'preshared-key',
    '2' => 'dss-signature',
    '3' => 'rsa-signature',
    '4' => 'rsa-encryption',
    '5' => 'rev-rsa-encryption',
    '129' => 'xauth',
    '130' => 'crack',
  },
  tunnelType => {
    '1' => 'regular',
    '2' => 'permanent',
  },
  permanentTunnelPeerType => {
    '1' => 'regular',
    '2' => 'daip',
    '3' => 'robo',
  },
  permanentTunnelProbState => {
    '0' => 'unknown',
    '1' => 'alive',
    '2' => 'dead',
  },
  raTunnelEncAlgorithm => {
    '1' => 'espDES',
    '2' => 'esp3DES',
    '5' => 'espCAST',
    '7' => 'esp3IDEA',
    '9' => 'espNULL',
    '129' => 'espAES128',
    '130' => 'espAES256',
  },
  tunnelLinkPriority => {
    '0' => 'primary',
    '1' => 'backup',
    '2' => 'on-demand',
  },
  raUserState => {
    '3' => 'active',
    '4' => 'destroy',
    '129' => 'idle',
    '130' => 'phase1',
    '131' => 'down',
    '132' => 'init',
  },
  permanentTunnelLinkPriority => {
    '0' => 'primary',
    '1' => 'backup',
    '2' => 'on-demand',
  },
  fwSXLStatus => {
    '0' => 'disabled',
    '1' => 'enabled',
  },
  tunnelPeerType => {
    '1' => 'regular',
    '2' => 'daip',
    '3' => 'robo',
  },
  tunnelState => {
    '3' => 'active',
    '4' => 'destroy',
    '129' => 'idle',
    '130' => 'phase1',
    '131' => 'down',
    '132' => 'init',
  },
  permanentTunnelState => {
    '3' => 'active',
    '4' => 'destroy',
    '129' => 'idle',
    '130' => 'phase1',
    '131' => 'down',
    '132' => 'init',
  },
  tunnelProbState => {
    '0' => 'unknown',
    '1' => 'alive',
    '2' => 'dead',
  },
};
